@@ -340,7 +340,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def add_association(
+    def add_association_unary(
         self,
         request: Union[compute.AddAssociationFirewallPolicyRequest, dict] = None,
         *,
@@ -432,7 +432,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def add_rule(
+    def add_rule_unary(
         self,
         request: Union[compute.AddRuleFirewallPolicyRequest, dict] = None,
         *,
@@ -519,7 +519,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def clone_rules(
+    def clone_rules_unary(
         self,
         request: Union[compute.CloneRulesFirewallPolicyRequest, dict] = None,
         *,
@@ -598,7 +598,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteFirewallPolicyRequest, dict] = None,
         *,
@@ -977,10 +977,11 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertFirewallPolicyRequest, dict] = None,
         *,
+        parent_id: str = None,
         firewall_policy_resource: compute.FirewallPolicy = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -994,6 +995,15 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
                 The request object. A request message for
                 FirewallPolicies.Insert. See the method description for
                 details.
+            parent_id (str):
+                Parent ID for this request. The ID can be either be
+                "folders/[FOLDER_ID]" if the parent is a folder or
+                "organizations/[ORGANIZATION_ID]" if the parent is an
+                organization.
+
+                This corresponds to the ``parent_id`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
             firewall_policy_resource (google.cloud.compute_v1.types.FirewallPolicy):
                 The body resource for this request
                 This corresponds to the ``firewall_policy_resource`` field
@@ -1027,7 +1037,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = any([firewall_policy_resource])
+        has_flattened_params = any([parent_id, firewall_policy_resource])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -1042,6 +1052,8 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
             request = compute.InsertFirewallPolicyRequest(request)
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
+            if parent_id is not None:
+                request.parent_id = parent_id
             if firewall_policy_resource is not None:
                 request.firewall_policy_resource = firewall_policy_resource
 
@@ -1152,11 +1164,12 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def move(
+    def move_unary(
         self,
         request: Union[compute.MoveFirewallPolicyRequest, dict] = None,
         *,
         firewall_policy: str = None,
+        parent_id: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1175,6 +1188,13 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
                 This corresponds to the ``firewall_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
+            parent_id (str):
+                The new parent of the firewall
+                policy.
+
+                This corresponds to the ``parent_id`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1203,7 +1223,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        has_flattened_params = any([firewall_policy])
+        has_flattened_params = any([firewall_policy, parent_id])
         if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
@@ -1220,6 +1240,8 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
             # request, apply these.
             if firewall_policy is not None:
                 request.firewall_policy = firewall_policy
+            if parent_id is not None:
+                request.parent_id = parent_id
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1231,7 +1253,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def patch(
+    def patch_unary(
         self,
         request: Union[compute.PatchFirewallPolicyRequest, dict] = None,
         *,
@@ -1319,7 +1341,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def patch_rule(
+    def patch_rule_unary(
         self,
         request: Union[compute.PatchRuleFirewallPolicyRequest, dict] = None,
         *,
@@ -1406,7 +1428,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def remove_association(
+    def remove_association_unary(
         self,
         request: Union[compute.RemoveAssociationFirewallPolicyRequest, dict] = None,
         *,
@@ -1486,7 +1508,7 @@ class FirewallPoliciesClient(metaclass=FirewallPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def remove_rule(
+    def remove_rule_unary(
         self,
         request: Union[compute.RemoveRuleFirewallPolicyRequest, dict] = None,
         *,
