@@ -338,7 +338,7 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteInterconnectRequest, dict] = None,
         *,
@@ -575,7 +575,7 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertInterconnectRequest, dict] = None,
         *,
@@ -735,7 +735,7 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # Done; return the response.
         return response
 
-    def patch(
+    def patch_unary(
         self,
         request: Union[compute.PatchInterconnectRequest, dict] = None,
         *,
