@@ -338,7 +338,7 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteLicenseRequest, dict] = None,
         *,
@@ -618,7 +618,7 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertLicenseRequest, dict] = None,
         *,
