@@ -14,22 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.compute_v1.services.node_types import pagers
 from google.cloud.compute_v1.types import compute
 from .transports.base import NodeTypesTransport, DEFAULT_CLIENT_INFO
@@ -261,8 +265,15 @@ class NodeTypesClient(metaclass=NodeTypesClientMeta):
             client_options = client_options_lib.ClientOptions()
 
         # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") not in (
+            "true",
+            "false",
+        ):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        use_client_cert = (
+            os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") == "true"
         )
 
         client_cert_source_func = None
@@ -324,21 +335,22 @@ class NodeTypesClient(metaclass=NodeTypesClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def aggregated_list(
         self,
-        request: compute.AggregatedListNodeTypesRequest = None,
+        request: Union[compute.AggregatedListNodeTypesRequest, dict] = None,
         *,
         project: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.AggregatedListPager:
         r"""Retrieves an aggregated list of node types.
 
         Args:
-            request (google.cloud.compute_v1.types.AggregatedListNodeTypesRequest):
+            request (Union[google.cloud.compute_v1.types.AggregatedListNodeTypesRequest, dict]):
                 The request object. A request message for
                 NodeTypes.AggregatedList. See the method description for
                 details.
@@ -399,12 +411,12 @@ class NodeTypesClient(metaclass=NodeTypesClientMeta):
 
     def get(
         self,
-        request: compute.GetNodeTypeRequest = None,
+        request: Union[compute.GetNodeTypeRequest, dict] = None,
         *,
         project: str = None,
         zone: str = None,
         node_type: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> compute.NodeType:
@@ -412,7 +424,7 @@ class NodeTypesClient(metaclass=NodeTypesClientMeta):
         available node types by making a list() request.
 
         Args:
-            request (google.cloud.compute_v1.types.GetNodeTypeRequest):
+            request (Union[google.cloud.compute_v1.types.GetNodeTypeRequest, dict]):
                 The request object. A request message for NodeTypes.Get.
                 See the method description for details.
             project (str):
@@ -489,11 +501,11 @@ class NodeTypesClient(metaclass=NodeTypesClientMeta):
 
     def list(
         self,
-        request: compute.ListNodeTypesRequest = None,
+        request: Union[compute.ListNodeTypesRequest, dict] = None,
         *,
         project: str = None,
         zone: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPager:
@@ -501,7 +513,7 @@ class NodeTypesClient(metaclass=NodeTypesClientMeta):
         specified project.
 
         Args:
-            request (google.cloud.compute_v1.types.ListNodeTypesRequest):
+            request (Union[google.cloud.compute_v1.types.ListNodeTypesRequest, dict]):
                 The request object. A request message for
                 NodeTypes.List. See the method description for details.
             project (str):
@@ -569,6 +581,19 @@ class NodeTypesClient(metaclass=NodeTypesClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
