@@ -342,7 +342,7 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteRegionAutoscalerRequest, dict] = None,
         *,
@@ -528,7 +528,7 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertRegionAutoscalerRequest, dict] = None,
         *,
@@ -707,7 +707,7 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # Done; return the response.
         return response
 
-    def patch(
+    def patch_unary(
         self,
         request: Union[compute.PatchRegionAutoscalerRequest, dict] = None,
         *,
@@ -805,7 +805,7 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # Done; return the response.
         return response
 
-    def update(
+    def update_unary(
         self,
         request: Union[compute.UpdateRegionAutoscalerRequest, dict] = None,
         *,
