@@ -338,7 +338,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def add_resource_policies(
+    def add_resource_policies_unary(
         self,
         request: Union[compute.AddResourcePoliciesRegionDiskRequest, dict] = None,
         *,
@@ -447,7 +447,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # Done; return the response.
         return response
 
-    def create_snapshot(
+    def create_snapshot_unary(
         self,
         request: Union[compute.CreateSnapshotRegionDiskRequest, dict] = None,
         *,
@@ -550,7 +550,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # Done; return the response.
         return response
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteRegionDiskRequest, dict] = None,
         *,
@@ -862,7 +862,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertRegionDiskRequest, dict] = None,
         *,
@@ -1037,7 +1037,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # Done; return the response.
         return response
 
-    def remove_resource_policies(
+    def remove_resource_policies_unary(
         self,
         request: Union[compute.RemoveResourcePoliciesRegionDiskRequest, dict] = None,
         *,
@@ -1149,7 +1149,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # Done; return the response.
         return response
 
-    def resize(
+    def resize_unary(
         self,
         request: Union[compute.ResizeRegionDiskRequest, dict] = None,
         *,
@@ -1388,7 +1388,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # Done; return the response.
         return response
 
-    def set_labels(
+    def set_labels_unary(
         self,
         request: Union[compute.SetLabelsRegionDiskRequest, dict] = None,
         *,
