@@ -344,7 +344,7 @@ class RegionNetworkEndpointGroupsClient(
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteRegionNetworkEndpointGroupRequest, dict] = None,
         *,
@@ -541,7 +541,7 @@ class RegionNetworkEndpointGroupsClient(
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertRegionNetworkEndpointGroupRequest, dict] = None,
         *,
