@@ -344,7 +344,7 @@ class RegionNotificationEndpointsClient(
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteRegionNotificationEndpointRequest, dict] = None,
         *,
@@ -532,7 +532,7 @@ class RegionNotificationEndpointsClient(
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertRegionNotificationEndpointRequest, dict] = None,
         *,
