@@ -410,7 +410,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # Done; return the response.
         return response
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteRouterRequest, dict] = None,
         *,
@@ -759,7 +759,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertRouterRequest, dict] = None,
         *,
@@ -932,7 +932,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # Done; return the response.
         return response
 
-    def patch(
+    def patch_unary(
         self,
         request: Union[compute.PatchRouterRequest, dict] = None,
         *,
@@ -1122,7 +1122,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # Done; return the response.
         return response
 
-    def update(
+    def update_unary(
         self,
         request: Union[compute.UpdateRouterRequest, dict] = None,
         *,
