@@ -338,7 +338,7 @@ class RoutesClient(metaclass=RoutesClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteRouteRequest, dict] = None,
         *,
@@ -498,7 +498,7 @@ class RoutesClient(metaclass=RoutesClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertRouteRequest, dict] = None,
         *,
