@@ -340,7 +340,7 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def add_rule(
+    def add_rule_unary(
         self,
         request: Union[compute.AddRuleSecurityPolicyRequest, dict] = None,
         *,
@@ -437,7 +437,7 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteSecurityPolicyRequest, dict] = None,
         *,
@@ -677,7 +677,7 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertSecurityPolicyRequest, dict] = None,
         *,
@@ -906,7 +906,7 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def patch(
+    def patch_unary(
         self,
         request: Union[compute.PatchSecurityPolicyRequest, dict] = None,
         *,
@@ -1004,7 +1004,7 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def patch_rule(
+    def patch_rule_unary(
         self,
         request: Union[compute.PatchRuleSecurityPolicyRequest, dict] = None,
         *,
@@ -1101,7 +1101,7 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def remove_rule(
+    def remove_rule_unary(
         self,
         request: Union[compute.RemoveRuleSecurityPolicyRequest, dict] = None,
         *,
