@@ -338,7 +338,7 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteSnapshotRequest, dict] = None,
         *,
@@ -817,7 +817,7 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # Done; return the response.
         return response
 
-    def set_labels(
+    def set_labels_unary(
         self,
         request: Union[compute.SetLabelsSnapshotRequest, dict] = None,
         *,
