@@ -338,7 +338,7 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteSslPolicyRequest, dict] = None,
         *,
@@ -507,7 +507,7 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertSslPolicyRequest, dict] = None,
         *,
@@ -729,7 +729,7 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # Done; return the response.
         return response
 
-    def patch(
+    def patch_unary(
         self,
         request: Union[compute.PatchSslPolicyRequest, dict] = None,
         *,
