@@ -416,7 +416,7 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # Done; return the response.
         return response
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteTargetHttpProxyRequest, dict] = None,
         *,
@@ -590,7 +590,7 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertTargetHttpProxyRequest, dict] = None,
         *,
@@ -749,7 +749,7 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # Done; return the response.
         return response
 
-    def patch(
+    def patch_unary(
         self,
         request: Union[compute.PatchTargetHttpProxyRequest, dict] = None,
         *,
@@ -849,7 +849,7 @@ class TargetHttpProxiesClient(metaclass=TargetHttpProxiesClientMeta):
         # Done; return the response.
         return response
 
-    def set_url_map(
+    def set_url_map_unary(
         self,
         request: Union[compute.SetUrlMapTargetHttpProxyRequest, dict] = None,
         *,
