@@ -340,7 +340,7 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
                 always_use_jwt_access=True,
             )
 
-    def delete(
+    def delete_unary(
         self,
         request: Union[compute.DeleteTargetTcpProxyRequest, dict] = None,
         *,
@@ -509,7 +509,7 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
         # Done; return the response.
         return response
 
-    def insert(
+    def insert_unary(
         self,
         request: Union[compute.InsertTargetTcpProxyRequest, dict] = None,
         *,
@@ -669,7 +669,7 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
         # Done; return the response.
         return response
 
-    def set_backend_service(
+    def set_backend_service_unary(
         self,
         request: Union[compute.SetBackendServiceTargetTcpProxyRequest, dict] = None,
         *,
@@ -773,7 +773,7 @@ class TargetTcpProxiesClient(metaclass=TargetTcpProxiesClientMeta):
         # Done; return the response.
         return response
 
-    def set_proxy_header(
+    def set_proxy_header_unary(
         self,
         request: Union[compute.SetProxyHeaderTargetTcpProxyRequest, dict] = None,
         *,
