@@ -66,6 +66,7 @@ from .compute import (
     AggregatedListReservationsRequest,
     AggregatedListResourcePoliciesRequest,
     AggregatedListRoutersRequest,
+    AggregatedListServiceAttachmentsRequest,
     AggregatedListSslCertificatesRequest,
     AggregatedListSubnetworksRequest,
     AggregatedListTargetHttpProxiesRequest,
@@ -204,6 +205,7 @@ from .compute import (
     DeleteRouteRequest,
     DeleteRouterRequest,
     DeleteSecurityPolicyRequest,
+    DeleteServiceAttachmentRequest,
     DeleteSignedUrlKeyBackendBucketRequest,
     DeleteSignedUrlKeyBackendServiceRequest,
     DeleteSnapshotRequest,
@@ -315,8 +317,10 @@ from .compute import (
     GetIamPolicyRegionDiskRequest,
     GetIamPolicyReservationRequest,
     GetIamPolicyResourcePolicyRequest,
+    GetIamPolicyServiceAttachmentRequest,
     GetIamPolicySnapshotRequest,
     GetIamPolicySubnetworkRequest,
+    GetImageFamilyViewRequest,
     GetImageRequest,
     GetInstanceGroupManagerRequest,
     GetInstanceGroupRequest,
@@ -365,6 +369,7 @@ from .compute import (
     GetScreenshotInstanceRequest,
     GetSecurityPolicyRequest,
     GetSerialPortOutputInstanceRequest,
+    GetServiceAttachmentRequest,
     GetShieldedInstanceIdentityInstanceRequest,
     GetSnapshotRequest,
     GetSslCertificateRequest,
@@ -424,6 +429,7 @@ from .compute import (
     HttpRouteRuleMatch,
     HTTPSHealthCheck,
     Image,
+    ImageFamilyView,
     ImageList,
     InitialStateConfig,
     InsertAddressRequest,
@@ -473,6 +479,7 @@ from .compute import (
     InsertRouteRequest,
     InsertRouterRequest,
     InsertSecurityPolicyRequest,
+    InsertServiceAttachmentRequest,
     InsertSslCertificateRequest,
     InsertSslPolicyRequest,
     InsertSubnetworkRequest,
@@ -647,6 +654,7 @@ from .compute import (
     ListRoutersRequest,
     ListRoutesRequest,
     ListSecurityPoliciesRequest,
+    ListServiceAttachmentsRequest,
     ListSnapshotsRequest,
     ListSslCertificatesRequest,
     ListSslPoliciesRequest,
@@ -780,6 +788,7 @@ from .compute import (
     PatchRuleFirewallPolicyRequest,
     PatchRuleSecurityPolicyRequest,
     PatchSecurityPolicyRequest,
+    PatchServiceAttachmentRequest,
     PatchSslPolicyRequest,
     PatchSubnetworkRequest,
     PatchTargetGrpcProxyRequest,
@@ -885,22 +894,27 @@ from .compute import (
     ResourcePolicyWeeklyCycle,
     ResourcePolicyWeeklyCycleDayOfWeek,
     Route,
+    RouteAsPath,
     RouteList,
     Router,
     RouterAdvertisedIpRange,
     RouterAggregatedList,
     RouterBgp,
     RouterBgpPeer,
+    RouterBgpPeerBfd,
     RouterInterface,
     RouterList,
     RouterNat,
     RouterNatLogConfig,
+    RouterNatRule,
+    RouterNatRuleAction,
     RouterNatSubnetworkToNat,
     RoutersPreviewResponse,
     RoutersScopedList,
     RouterStatus,
     RouterStatusBgpPeerStatus,
     RouterStatusNatStatus,
+    RouterStatusNatStatusNatRuleStatus,
     RouterStatusResponse,
     Rule,
     ScalingScheduleStatus,
@@ -911,15 +925,26 @@ from .compute import (
     SecurityPoliciesListPreconfiguredExpressionSetsResponse,
     SecurityPoliciesWafConfig,
     SecurityPolicy,
+    SecurityPolicyAdaptiveProtectionConfig,
+    SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig,
+    SecurityPolicyAdvancedOptionsConfig,
     SecurityPolicyList,
     SecurityPolicyReference,
     SecurityPolicyRule,
     SecurityPolicyRuleMatcher,
     SecurityPolicyRuleMatcherConfig,
     SecuritySettings,
+    SendDiagnosticInterruptInstanceRequest,
+    SendDiagnosticInterruptInstanceResponse,
     SerialPortOutput,
     ServerBinding,
     ServiceAccount,
+    ServiceAttachment,
+    ServiceAttachmentAggregatedList,
+    ServiceAttachmentConnectedEndpoint,
+    ServiceAttachmentConsumerProjectLimit,
+    ServiceAttachmentList,
+    ServiceAttachmentsScopedList,
     SetBackendServiceTargetSslProxyRequest,
     SetBackendServiceTargetTcpProxyRequest,
     SetBackupTargetPoolRequest,
@@ -938,6 +963,7 @@ from .compute import (
     SetIamPolicyRegionDiskRequest,
     SetIamPolicyReservationRequest,
     SetIamPolicyResourcePolicyRequest,
+    SetIamPolicyServiceAttachmentRequest,
     SetIamPolicySnapshotRequest,
     SetIamPolicySubnetworkRequest,
     SetInstanceTemplateInstanceGroupManagerRequest,
@@ -1015,6 +1041,7 @@ from .compute import (
     SubnetworksExpandIpCidrRangeRequest,
     SubnetworksScopedList,
     SubnetworksSetPrivateIpGoogleAccessRequest,
+    Subsetting,
     SwitchToCustomModeNetworkRequest,
     Tags,
     TargetGrpcProxy,
@@ -1073,11 +1100,13 @@ from .compute import (
     TestIamPermissionsRegionDiskRequest,
     TestIamPermissionsReservationRequest,
     TestIamPermissionsResourcePolicyRequest,
+    TestIamPermissionsServiceAttachmentRequest,
     TestIamPermissionsSnapshotRequest,
     TestIamPermissionsSubnetworkRequest,
     TestIamPermissionsVpnGatewayRequest,
     TestPermissionsRequest,
     TestPermissionsResponse,
+    Uint128,
     UpdateAccessConfigInstanceRequest,
     UpdateAutoscalerRequest,
     UpdateBackendBucketRequest,
@@ -1200,6 +1229,7 @@ __all__ = (
     "AggregatedListReservationsRequest",
     "AggregatedListResourcePoliciesRequest",
     "AggregatedListRoutersRequest",
+    "AggregatedListServiceAttachmentsRequest",
     "AggregatedListSslCertificatesRequest",
     "AggregatedListSubnetworksRequest",
     "AggregatedListTargetHttpProxiesRequest",
@@ -1338,6 +1368,7 @@ __all__ = (
     "DeleteRouteRequest",
     "DeleteRouterRequest",
     "DeleteSecurityPolicyRequest",
+    "DeleteServiceAttachmentRequest",
     "DeleteSignedUrlKeyBackendBucketRequest",
     "DeleteSignedUrlKeyBackendServiceRequest",
     "DeleteSnapshotRequest",
@@ -1449,8 +1480,10 @@ __all__ = (
     "GetIamPolicyRegionDiskRequest",
     "GetIamPolicyReservationRequest",
     "GetIamPolicyResourcePolicyRequest",
+    "GetIamPolicyServiceAttachmentRequest",
     "GetIamPolicySnapshotRequest",
     "GetIamPolicySubnetworkRequest",
+    "GetImageFamilyViewRequest",
     "GetImageRequest",
     "GetInstanceGroupManagerRequest",
     "GetInstanceGroupRequest",
@@ -1499,6 +1532,7 @@ __all__ = (
     "GetScreenshotInstanceRequest",
     "GetSecurityPolicyRequest",
     "GetSerialPortOutputInstanceRequest",
+    "GetServiceAttachmentRequest",
     "GetShieldedInstanceIdentityInstanceRequest",
     "GetSnapshotRequest",
     "GetSslCertificateRequest",
@@ -1558,6 +1592,7 @@ __all__ = (
     "HttpRouteRuleMatch",
     "HTTPSHealthCheck",
     "Image",
+    "ImageFamilyView",
     "ImageList",
     "InitialStateConfig",
     "InsertAddressRequest",
@@ -1607,6 +1642,7 @@ __all__ = (
     "InsertRouteRequest",
     "InsertRouterRequest",
     "InsertSecurityPolicyRequest",
+    "InsertServiceAttachmentRequest",
     "InsertSslCertificateRequest",
     "InsertSslPolicyRequest",
     "InsertSubnetworkRequest",
@@ -1781,6 +1817,7 @@ __all__ = (
     "ListRoutersRequest",
     "ListRoutesRequest",
     "ListSecurityPoliciesRequest",
+    "ListServiceAttachmentsRequest",
     "ListSnapshotsRequest",
     "ListSslCertificatesRequest",
     "ListSslPoliciesRequest",
@@ -1914,6 +1951,7 @@ __all__ = (
     "PatchRuleFirewallPolicyRequest",
     "PatchRuleSecurityPolicyRequest",
     "PatchSecurityPolicyRequest",
+    "PatchServiceAttachmentRequest",
     "PatchSslPolicyRequest",
     "PatchSubnetworkRequest",
     "PatchTargetGrpcProxyRequest",
@@ -2019,22 +2057,27 @@ __all__ = (
     "ResourcePolicyWeeklyCycle",
     "ResourcePolicyWeeklyCycleDayOfWeek",
     "Route",
+    "RouteAsPath",
     "RouteList",
     "Router",
     "RouterAdvertisedIpRange",
     "RouterAggregatedList",
     "RouterBgp",
     "RouterBgpPeer",
+    "RouterBgpPeerBfd",
     "RouterInterface",
     "RouterList",
     "RouterNat",
     "RouterNatLogConfig",
+    "RouterNatRule",
+    "RouterNatRuleAction",
     "RouterNatSubnetworkToNat",
     "RoutersPreviewResponse",
     "RoutersScopedList",
     "RouterStatus",
     "RouterStatusBgpPeerStatus",
     "RouterStatusNatStatus",
+    "RouterStatusNatStatusNatRuleStatus",
     "RouterStatusResponse",
     "Rule",
     "ScalingScheduleStatus",
@@ -2045,15 +2088,26 @@ __all__ = (
     "SecurityPoliciesListPreconfiguredExpressionSetsResponse",
     "SecurityPoliciesWafConfig",
     "SecurityPolicy",
+    "SecurityPolicyAdaptiveProtectionConfig",
+    "SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig",
+    "SecurityPolicyAdvancedOptionsConfig",
     "SecurityPolicyList",
     "SecurityPolicyReference",
     "SecurityPolicyRule",
     "SecurityPolicyRuleMatcher",
     "SecurityPolicyRuleMatcherConfig",
     "SecuritySettings",
+    "SendDiagnosticInterruptInstanceRequest",
+    "SendDiagnosticInterruptInstanceResponse",
     "SerialPortOutput",
     "ServerBinding",
     "ServiceAccount",
+    "ServiceAttachment",
+    "ServiceAttachmentAggregatedList",
+    "ServiceAttachmentConnectedEndpoint",
+    "ServiceAttachmentConsumerProjectLimit",
+    "ServiceAttachmentList",
+    "ServiceAttachmentsScopedList",
     "SetBackendServiceTargetSslProxyRequest",
     "SetBackendServiceTargetTcpProxyRequest",
     "SetBackupTargetPoolRequest",
@@ -2072,6 +2126,7 @@ __all__ = (
     "SetIamPolicyRegionDiskRequest",
     "SetIamPolicyReservationRequest",
     "SetIamPolicyResourcePolicyRequest",
+    "SetIamPolicyServiceAttachmentRequest",
     "SetIamPolicySnapshotRequest",
     "SetIamPolicySubnetworkRequest",
     "SetInstanceTemplateInstanceGroupManagerRequest",
@@ -2149,6 +2204,7 @@ __all__ = (
     "SubnetworksExpandIpCidrRangeRequest",
     "SubnetworksScopedList",
     "SubnetworksSetPrivateIpGoogleAccessRequest",
+    "Subsetting",
     "SwitchToCustomModeNetworkRequest",
     "Tags",
     "TargetGrpcProxy",
@@ -2207,11 +2263,13 @@ __all__ = (
     "TestIamPermissionsRegionDiskRequest",
     "TestIamPermissionsReservationRequest",
     "TestIamPermissionsResourcePolicyRequest",
+    "TestIamPermissionsServiceAttachmentRequest",
     "TestIamPermissionsSnapshotRequest",
     "TestIamPermissionsSubnetworkRequest",
     "TestIamPermissionsVpnGatewayRequest",
     "TestPermissionsRequest",
     "TestPermissionsResponse",
+    "Uint128",
     "UpdateAccessConfigInstanceRequest",
     "UpdateAutoscalerRequest",
     "UpdateBackendBucketRequest",
