@@ -574,7 +574,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteAddressRequest
 ):
     client = AddressesClient(
@@ -619,7 +619,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -647,7 +647,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteAddressRequest
 ):
     client = AddressesClient(
@@ -667,14 +667,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = AddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -704,7 +704,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", region="region_value", address="address_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -717,7 +717,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = AddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -725,7 +725,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteAddressRequest(),
             project="project_value",
             region="region_value",
@@ -747,20 +747,20 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetAddressReques
         # Designate an appropriate value for the returned response.
         return_value = compute.Address(
             address="address_value",
-            address_type=compute.Address.AddressType.EXTERNAL,
+            address_type="address_type_value",
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             id=205,
-            ip_version=compute.Address.IpVersion.IPV4,
+            ip_version="ip_version_value",
             kind="kind_value",
             name="name_value",
             network="network_value",
-            network_tier=compute.Address.NetworkTier.PREMIUM,
+            network_tier="network_tier_value",
             prefix_length=1391,
-            purpose=compute.Address.Purpose.DNS_RESOLVER,
+            purpose="purpose_value",
             region="region_value",
             self_link="self_link_value",
-            status=compute.Address.Status.IN_USE,
+            status="status_value",
             subnetwork="subnetwork_value",
             users=["users_value"],
         )
@@ -776,20 +776,20 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetAddressReques
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Address)
     assert response.address == "address_value"
-    assert response.address_type == compute.Address.AddressType.EXTERNAL
+    assert response.address_type == "address_type_value"
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.id == 205
-    assert response.ip_version == compute.Address.IpVersion.IPV4
+    assert response.ip_version == "ip_version_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
-    assert response.network_tier == compute.Address.NetworkTier.PREMIUM
+    assert response.network_tier == "network_tier_value"
     assert response.prefix_length == 1391
-    assert response.purpose == compute.Address.Purpose.DNS_RESOLVER
+    assert response.purpose == "purpose_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
-    assert response.status == compute.Address.Status.IN_USE
+    assert response.status == "status_value"
     assert response.subnetwork == "subnetwork_value"
     assert response.users == ["users_value"]
 
@@ -880,7 +880,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertAddressRequest
 ):
     client = AddressesClient(
@@ -926,7 +926,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -954,7 +954,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertAddressRequest
 ):
     client = AddressesClient(
@@ -975,14 +975,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = AddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1010,7 +1010,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             address_resource=compute.Address(address="address_value"),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1023,7 +1023,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = AddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1031,7 +1031,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertAddressRequest(),
             project="project_value",
             region="region_value",
