@@ -409,7 +409,7 @@ def test_backend_buckets_client_client_options_credentials_file(
         )
 
 
-def test_add_signed_url_key_rest(
+def test_add_signed_url_key_unary_rest(
     transport: str = "rest", request_type=compute.AddSignedUrlKeyBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -457,7 +457,7 @@ def test_add_signed_url_key_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.add_signed_url_key(request)
+        response = client.add_signed_url_key_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -485,7 +485,7 @@ def test_add_signed_url_key_rest(
     assert response.zone == "zone_value"
 
 
-def test_add_signed_url_key_rest_bad_request(
+def test_add_signed_url_key_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.AddSignedUrlKeyBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -508,14 +508,14 @@ def test_add_signed_url_key_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.add_signed_url_key(request)
+        client.add_signed_url_key_unary(request)
 
 
-def test_add_signed_url_key_rest_from_dict():
-    test_add_signed_url_key_rest(request_type=dict)
+def test_add_signed_url_key_unary_rest_from_dict():
+    test_add_signed_url_key_unary_rest(request_type=dict)
 
 
-def test_add_signed_url_key_rest_flattened(transport: str = "rest"):
+def test_add_signed_url_key_unary_rest_flattened(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -543,7 +543,7 @@ def test_add_signed_url_key_rest_flattened(transport: str = "rest"):
             signed_url_key_resource=compute.SignedUrlKey(key_name="key_name_value"),
         )
         mock_args.update(sample_request)
-        client.add_signed_url_key(**mock_args)
+        client.add_signed_url_key_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -556,7 +556,7 @@ def test_add_signed_url_key_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_add_signed_url_key_rest_flattened_error(transport: str = "rest"):
+def test_add_signed_url_key_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -564,7 +564,7 @@ def test_add_signed_url_key_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.add_signed_url_key(
+        client.add_signed_url_key_unary(
             compute.AddSignedUrlKeyBackendBucketRequest(),
             project="project_value",
             backend_bucket="backend_bucket_value",
@@ -572,7 +572,7 @@ def test_add_signed_url_key_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -617,7 +617,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -645,7 +645,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -665,14 +665,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -698,7 +698,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", backend_bucket="backend_bucket_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -711,7 +711,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -719,14 +719,14 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteBackendBucketRequest(),
             project="project_value",
             backend_bucket="backend_bucket_value",
         )
 
 
-def test_delete_signed_url_key_rest(
+def test_delete_signed_url_key_unary_rest(
     transport: str = "rest", request_type=compute.DeleteSignedUrlKeyBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -771,7 +771,7 @@ def test_delete_signed_url_key_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete_signed_url_key(request)
+        response = client.delete_signed_url_key_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -799,7 +799,7 @@ def test_delete_signed_url_key_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_signed_url_key_rest_bad_request(
+def test_delete_signed_url_key_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteSignedUrlKeyBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -819,14 +819,14 @@ def test_delete_signed_url_key_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete_signed_url_key(request)
+        client.delete_signed_url_key_unary(request)
 
 
-def test_delete_signed_url_key_rest_from_dict():
-    test_delete_signed_url_key_rest(request_type=dict)
+def test_delete_signed_url_key_unary_rest_from_dict():
+    test_delete_signed_url_key_unary_rest(request_type=dict)
 
 
-def test_delete_signed_url_key_rest_flattened(transport: str = "rest"):
+def test_delete_signed_url_key_unary_rest_flattened(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -854,7 +854,7 @@ def test_delete_signed_url_key_rest_flattened(transport: str = "rest"):
             key_name="key_name_value",
         )
         mock_args.update(sample_request)
-        client.delete_signed_url_key(**mock_args)
+        client.delete_signed_url_key_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -867,7 +867,7 @@ def test_delete_signed_url_key_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_signed_url_key_rest_flattened_error(transport: str = "rest"):
+def test_delete_signed_url_key_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -875,7 +875,7 @@ def test_delete_signed_url_key_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete_signed_url_key(
+        client.delete_signed_url_key_unary(
             compute.DeleteSignedUrlKeyBackendBucketRequest(),
             project="project_value",
             backend_bucket="backend_bucket_value",
@@ -1011,7 +1011,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -1059,7 +1059,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1087,7 +1087,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -1110,14 +1110,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1146,7 +1146,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1159,7 +1159,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1167,7 +1167,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertBackendBucketRequest(),
             project="project_value",
             backend_bucket_resource=compute.BackendBucket(
@@ -1339,7 +1339,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -1387,7 +1387,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1415,7 +1415,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -1438,14 +1438,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1475,7 +1475,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1488,7 +1488,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1496,7 +1496,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchBackendBucketRequest(),
             project="project_value",
             backend_bucket="backend_bucket_value",
@@ -1506,7 +1506,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_update_rest(
+def test_update_unary_rest(
     transport: str = "rest", request_type=compute.UpdateBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -1554,7 +1554,7 @@ def test_update_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1582,7 +1582,7 @@ def test_update_rest(
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateBackendBucketRequest
 ):
     client = BackendBucketsClient(
@@ -1605,14 +1605,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1642,7 +1642,7 @@ def test_update_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1655,7 +1655,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendBucketsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1663,7 +1663,7 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateBackendBucketRequest(),
             project="project_value",
             backend_bucket="backend_bucket_value",
