@@ -419,7 +419,7 @@ def test_backend_services_client_client_options_credentials_file(
         )
 
 
-def test_add_signed_url_key_rest(
+def test_add_signed_url_key_unary_rest(
     transport: str = "rest", request_type=compute.AddSignedUrlKeyBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -467,7 +467,7 @@ def test_add_signed_url_key_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.add_signed_url_key(request)
+        response = client.add_signed_url_key_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -495,7 +495,7 @@ def test_add_signed_url_key_rest(
     assert response.zone == "zone_value"
 
 
-def test_add_signed_url_key_rest_bad_request(
+def test_add_signed_url_key_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.AddSignedUrlKeyBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -518,14 +518,14 @@ def test_add_signed_url_key_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.add_signed_url_key(request)
+        client.add_signed_url_key_unary(request)
 
 
-def test_add_signed_url_key_rest_from_dict():
-    test_add_signed_url_key_rest(request_type=dict)
+def test_add_signed_url_key_unary_rest_from_dict():
+    test_add_signed_url_key_unary_rest(request_type=dict)
 
 
-def test_add_signed_url_key_rest_flattened(transport: str = "rest"):
+def test_add_signed_url_key_unary_rest_flattened(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -553,7 +553,7 @@ def test_add_signed_url_key_rest_flattened(transport: str = "rest"):
             signed_url_key_resource=compute.SignedUrlKey(key_name="key_name_value"),
         )
         mock_args.update(sample_request)
-        client.add_signed_url_key(**mock_args)
+        client.add_signed_url_key_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -566,7 +566,7 @@ def test_add_signed_url_key_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_add_signed_url_key_rest_flattened_error(transport: str = "rest"):
+def test_add_signed_url_key_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -574,7 +574,7 @@ def test_add_signed_url_key_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.add_signed_url_key(
+        client.add_signed_url_key_unary(
             compute.AddSignedUrlKeyBackendServiceRequest(),
             project="project_value",
             backend_service="backend_service_value",
@@ -765,7 +765,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -810,7 +810,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -838,7 +838,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -858,14 +858,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -891,7 +891,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", backend_service="backend_service_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -904,7 +904,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -912,14 +912,14 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteBackendServiceRequest(),
             project="project_value",
             backend_service="backend_service_value",
         )
 
 
-def test_delete_signed_url_key_rest(
+def test_delete_signed_url_key_unary_rest(
     transport: str = "rest",
     request_type=compute.DeleteSignedUrlKeyBackendServiceRequest,
 ):
@@ -965,7 +965,7 @@ def test_delete_signed_url_key_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete_signed_url_key(request)
+        response = client.delete_signed_url_key_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -993,7 +993,7 @@ def test_delete_signed_url_key_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_signed_url_key_rest_bad_request(
+def test_delete_signed_url_key_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.DeleteSignedUrlKeyBackendServiceRequest,
 ):
@@ -1014,14 +1014,14 @@ def test_delete_signed_url_key_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete_signed_url_key(request)
+        client.delete_signed_url_key_unary(request)
 
 
-def test_delete_signed_url_key_rest_from_dict():
-    test_delete_signed_url_key_rest(request_type=dict)
+def test_delete_signed_url_key_unary_rest_from_dict():
+    test_delete_signed_url_key_unary_rest(request_type=dict)
 
 
-def test_delete_signed_url_key_rest_flattened(transport: str = "rest"):
+def test_delete_signed_url_key_unary_rest_flattened(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1049,7 +1049,7 @@ def test_delete_signed_url_key_rest_flattened(transport: str = "rest"):
             key_name="key_name_value",
         )
         mock_args.update(sample_request)
-        client.delete_signed_url_key(**mock_args)
+        client.delete_signed_url_key_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1062,7 +1062,7 @@ def test_delete_signed_url_key_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_signed_url_key_rest_flattened_error(transport: str = "rest"):
+def test_delete_signed_url_key_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1070,7 +1070,7 @@ def test_delete_signed_url_key_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete_signed_url_key(
+        client.delete_signed_url_key_unary(
             compute.DeleteSignedUrlKeyBackendServiceRequest(),
             project="project_value",
             backend_service="backend_service_value",
@@ -1103,17 +1103,17 @@ def test_get_rest(
             health_checks=["health_checks_value"],
             id=205,
             kind="kind_value",
-            load_balancing_scheme=compute.BackendService.LoadBalancingScheme.EXTERNAL,
-            locality_lb_policy=compute.BackendService.LocalityLbPolicy.INVALID_LB_POLICY,
+            load_balancing_scheme="load_balancing_scheme_value",
+            locality_lb_policy="locality_lb_policy_value",
             name="name_value",
             network="network_value",
             port=453,
             port_name="port_name_value",
-            protocol=compute.BackendService.Protocol.GRPC,
+            protocol="protocol_value",
             region="region_value",
             security_policy="security_policy_value",
             self_link="self_link_value",
-            session_affinity=compute.BackendService.SessionAffinity.CLIENT_IP,
+            session_affinity="session_affinity_value",
             timeout_sec=1185,
         )
 
@@ -1137,23 +1137,17 @@ def test_get_rest(
     assert response.health_checks == ["health_checks_value"]
     assert response.id == 205
     assert response.kind == "kind_value"
-    assert (
-        response.load_balancing_scheme
-        == compute.BackendService.LoadBalancingScheme.EXTERNAL
-    )
-    assert (
-        response.locality_lb_policy
-        == compute.BackendService.LocalityLbPolicy.INVALID_LB_POLICY
-    )
+    assert response.load_balancing_scheme == "load_balancing_scheme_value"
+    assert response.locality_lb_policy == "locality_lb_policy_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
     assert response.port == 453
     assert response.port_name == "port_name_value"
-    assert response.protocol == compute.BackendService.Protocol.GRPC
+    assert response.protocol == "protocol_value"
     assert response.region == "region_value"
     assert response.security_policy == "security_policy_value"
     assert response.self_link == "self_link_value"
-    assert response.session_affinity == compute.BackendService.SessionAffinity.CLIENT_IP
+    assert response.session_affinity == "session_affinity_value"
     assert response.timeout_sec == 1185
 
 
@@ -1361,7 +1355,7 @@ def test_get_health_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -1409,7 +1403,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1437,7 +1431,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -1460,14 +1454,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1496,7 +1490,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1509,7 +1503,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1517,7 +1511,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertBackendServiceRequest(),
             project="project_value",
             backend_service_resource=compute.BackendService(
@@ -1689,7 +1683,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -1737,7 +1731,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1765,7 +1759,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -1788,14 +1782,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1825,7 +1819,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1838,7 +1832,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1846,7 +1840,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchBackendServiceRequest(),
             project="project_value",
             backend_service="backend_service_value",
@@ -1856,7 +1850,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_security_policy_rest(
+def test_set_security_policy_unary_rest(
     transport: str = "rest", request_type=compute.SetSecurityPolicyBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -1904,7 +1898,7 @@ def test_set_security_policy_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_security_policy(request)
+        response = client.set_security_policy_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1932,7 +1926,7 @@ def test_set_security_policy_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_security_policy_rest_bad_request(
+def test_set_security_policy_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetSecurityPolicyBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -1955,14 +1949,14 @@ def test_set_security_policy_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_security_policy(request)
+        client.set_security_policy_unary(request)
 
 
-def test_set_security_policy_rest_from_dict():
-    test_set_security_policy_rest(request_type=dict)
+def test_set_security_policy_unary_rest_from_dict():
+    test_set_security_policy_unary_rest(request_type=dict)
 
 
-def test_set_security_policy_rest_flattened(transport: str = "rest"):
+def test_set_security_policy_unary_rest_flattened(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1992,7 +1986,7 @@ def test_set_security_policy_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_security_policy(**mock_args)
+        client.set_security_policy_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -2005,7 +1999,7 @@ def test_set_security_policy_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_security_policy_rest_flattened_error(transport: str = "rest"):
+def test_set_security_policy_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2013,7 +2007,7 @@ def test_set_security_policy_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_security_policy(
+        client.set_security_policy_unary(
             compute.SetSecurityPolicyBackendServiceRequest(),
             project="project_value",
             backend_service="backend_service_value",
@@ -2023,7 +2017,7 @@ def test_set_security_policy_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_update_rest(
+def test_update_unary_rest(
     transport: str = "rest", request_type=compute.UpdateBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -2071,7 +2065,7 @@ def test_update_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -2099,7 +2093,7 @@ def test_update_rest(
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateBackendServiceRequest
 ):
     client = BackendServicesClient(
@@ -2122,14 +2116,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2159,7 +2153,7 @@ def test_update_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -2172,7 +2166,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = BackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2180,7 +2174,7 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateBackendServiceRequest(),
             project="project_value",
             backend_service="backend_service_value",
