@@ -422,7 +422,7 @@ def test_external_vpn_gateways_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
@@ -467,7 +467,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -495,7 +495,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
@@ -515,14 +515,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = ExternalVpnGatewaysClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -548,7 +548,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", external_vpn_gateway="external_vpn_gateway_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -561,7 +561,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = ExternalVpnGatewaysClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -569,7 +569,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteExternalVpnGatewayRequest(),
             project="project_value",
             external_vpn_gateway="external_vpn_gateway_value",
@@ -597,7 +597,7 @@ def test_get_rest(
             kind="kind_value",
             label_fingerprint="label_fingerprint_value",
             name="name_value",
-            redundancy_type=compute.ExternalVpnGateway.RedundancyType.FOUR_IPS_REDUNDANCY,
+            redundancy_type="redundancy_type_value",
             self_link="self_link_value",
         )
 
@@ -617,10 +617,7 @@ def test_get_rest(
     assert response.kind == "kind_value"
     assert response.label_fingerprint == "label_fingerprint_value"
     assert response.name == "name_value"
-    assert (
-        response.redundancy_type
-        == compute.ExternalVpnGateway.RedundancyType.FOUR_IPS_REDUNDANCY
-    )
+    assert response.redundancy_type == "redundancy_type_value"
     assert response.self_link == "self_link_value"
 
 
@@ -705,7 +702,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
@@ -753,7 +750,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -781,7 +778,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
@@ -804,14 +801,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = ExternalVpnGatewaysClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -840,7 +837,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -853,7 +850,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = ExternalVpnGatewaysClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -861,7 +858,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertExternalVpnGatewayRequest(),
             project="project_value",
             external_vpn_gateway_resource=compute.ExternalVpnGateway(
@@ -1037,7 +1034,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_set_labels_rest(
+def test_set_labels_unary_rest(
     transport: str = "rest", request_type=compute.SetLabelsExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
@@ -1085,7 +1082,7 @@ def test_set_labels_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_labels(request)
+        response = client.set_labels_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1113,7 +1110,7 @@ def test_set_labels_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_labels_rest_bad_request(
+def test_set_labels_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetLabelsExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
@@ -1136,14 +1133,14 @@ def test_set_labels_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_labels(request)
+        client.set_labels_unary(request)
 
 
-def test_set_labels_rest_from_dict():
-    test_set_labels_rest(request_type=dict)
+def test_set_labels_unary_rest_from_dict():
+    test_set_labels_unary_rest(request_type=dict)
 
 
-def test_set_labels_rest_flattened(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened(transport: str = "rest"):
     client = ExternalVpnGatewaysClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1173,7 +1170,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_labels(**mock_args)
+        client.set_labels_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1186,7 +1183,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_labels_rest_flattened_error(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened_error(transport: str = "rest"):
     client = ExternalVpnGatewaysClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1194,7 +1191,7 @@ def test_set_labels_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_labels(
+        client.set_labels_unary(
             compute.SetLabelsExternalVpnGatewayRequest(),
             project="project_value",
             resource="resource_value",
