@@ -397,7 +397,7 @@ def test_firewalls_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteFirewallRequest
 ):
     client = FirewallsClient(
@@ -442,7 +442,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -470,7 +470,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteFirewallRequest
 ):
     client = FirewallsClient(
@@ -490,14 +490,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -521,7 +521,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", firewall="firewall_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -534,7 +534,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -542,7 +542,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteFirewallRequest(),
             project="project_value",
             firewall="firewall_value",
@@ -565,7 +565,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetFirewallReque
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             destination_ranges=["destination_ranges_value"],
-            direction=compute.Firewall.Direction.EGRESS,
+            direction="direction_value",
             disabled=True,
             id=205,
             kind="kind_value",
@@ -593,7 +593,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetFirewallReque
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.destination_ranges == ["destination_ranges_value"]
-    assert response.direction == compute.Firewall.Direction.EGRESS
+    assert response.direction == "direction_value"
     assert response.disabled is True
     assert response.id == 205
     assert response.kind == "kind_value"
@@ -687,7 +687,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertFirewallRequest
 ):
     client = FirewallsClient(
@@ -735,7 +735,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -763,7 +763,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertFirewallRequest
 ):
     client = FirewallsClient(
@@ -786,14 +786,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -822,7 +822,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -835,7 +835,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -843,7 +843,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertFirewallRequest(),
             project="project_value",
             firewall_resource=compute.Firewall(
@@ -1005,7 +1005,9 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(transport: str = "rest", request_type=compute.PatchFirewallRequest):
+def test_patch_unary_rest(
+    transport: str = "rest", request_type=compute.PatchFirewallRequest
+):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1051,7 +1053,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchFirewallR
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1079,7 +1081,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchFirewallR
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchFirewallRequest
 ):
     client = FirewallsClient(
@@ -1102,14 +1104,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1139,7 +1141,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1152,7 +1154,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1160,7 +1162,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchFirewallRequest(),
             project="project_value",
             firewall="firewall_value",
@@ -1170,7 +1172,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_update_rest(
+def test_update_unary_rest(
     transport: str = "rest", request_type=compute.UpdateFirewallRequest
 ):
     client = FirewallsClient(
@@ -1218,7 +1220,7 @@ def test_update_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1246,7 +1248,7 @@ def test_update_rest(
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateFirewallRequest
 ):
     client = FirewallsClient(
@@ -1269,14 +1271,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1306,7 +1308,7 @@ def test_update_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1319,7 +1321,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = FirewallsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1327,7 +1329,7 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateFirewallRequest(),
             project="project_value",
             firewall="firewall_value",
