@@ -602,7 +602,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -651,7 +651,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -679,7 +679,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -703,14 +703,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -742,7 +742,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             forwarding_rule="forwarding_rule_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -755,7 +755,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -763,7 +763,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteForwardingRuleRequest(),
             project="project_value",
             region="region_value",
@@ -791,7 +791,7 @@ def test_get_rest(
         # Designate an appropriate value for the returned response.
         return_value = compute.ForwardingRule(
             I_p_address="I_p_address_value",
-            I_p_protocol=compute.ForwardingRule.IPProtocol.AH,
+            I_p_protocol="I_p_protocol_value",
             all_ports=True,
             allow_global_access=True,
             backend_service="backend_service_value",
@@ -799,18 +799,18 @@ def test_get_rest(
             description="description_value",
             fingerprint="fingerprint_value",
             id=205,
-            ip_version=compute.ForwardingRule.IpVersion.IPV4,
+            ip_version="ip_version_value",
             is_mirroring_collector=True,
             kind="kind_value",
             label_fingerprint="label_fingerprint_value",
-            load_balancing_scheme=compute.ForwardingRule.LoadBalancingScheme.EXTERNAL,
+            load_balancing_scheme="load_balancing_scheme_value",
             name="name_value",
             network="network_value",
-            network_tier=compute.ForwardingRule.NetworkTier.PREMIUM,
+            network_tier="network_tier_value",
             port_range="port_range_value",
             ports=["ports_value"],
             psc_connection_id=1793,
-            psc_connection_status=compute.ForwardingRule.PscConnectionStatus.ACCEPTED,
+            psc_connection_status="psc_connection_status_value",
             region="region_value",
             self_link="self_link_value",
             service_label="service_label_value",
@@ -830,7 +830,7 @@ def test_get_rest(
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.ForwardingRule)
     assert response.I_p_address == "I_p_address_value"
-    assert response.I_p_protocol == compute.ForwardingRule.IPProtocol.AH
+    assert response.I_p_protocol == "I_p_protocol_value"
     assert response.all_ports is True
     assert response.allow_global_access is True
     assert response.backend_service == "backend_service_value"
@@ -838,24 +838,18 @@ def test_get_rest(
     assert response.description == "description_value"
     assert response.fingerprint == "fingerprint_value"
     assert response.id == 205
-    assert response.ip_version == compute.ForwardingRule.IpVersion.IPV4
+    assert response.ip_version == "ip_version_value"
     assert response.is_mirroring_collector is True
     assert response.kind == "kind_value"
     assert response.label_fingerprint == "label_fingerprint_value"
-    assert (
-        response.load_balancing_scheme
-        == compute.ForwardingRule.LoadBalancingScheme.EXTERNAL
-    )
+    assert response.load_balancing_scheme == "load_balancing_scheme_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
-    assert response.network_tier == compute.ForwardingRule.NetworkTier.PREMIUM
+    assert response.network_tier == "network_tier_value"
     assert response.port_range == "port_range_value"
     assert response.ports == ["ports_value"]
     assert response.psc_connection_id == 1793
-    assert (
-        response.psc_connection_status
-        == compute.ForwardingRule.PscConnectionStatus.ACCEPTED
-    )
+    assert response.psc_connection_status == "psc_connection_status_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.service_label == "service_label_value"
@@ -956,7 +950,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1004,7 +998,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1032,7 +1026,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1055,14 +1049,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1092,7 +1086,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1105,7 +1099,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1113,7 +1107,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertForwardingRuleRequest(),
             project="project_value",
             region="region_value",
@@ -1288,7 +1282,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1340,7 +1334,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1368,7 +1362,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1395,14 +1389,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1437,7 +1431,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1450,7 +1444,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1458,7 +1452,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchForwardingRuleRequest(),
             project="project_value",
             region="region_value",
@@ -1469,7 +1463,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_labels_rest(
+def test_set_labels_unary_rest(
     transport: str = "rest", request_type=compute.SetLabelsForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1517,7 +1511,7 @@ def test_set_labels_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_labels(request)
+        response = client.set_labels_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1545,7 +1539,7 @@ def test_set_labels_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_labels_rest_bad_request(
+def test_set_labels_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetLabelsForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1568,14 +1562,14 @@ def test_set_labels_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_labels(request)
+        client.set_labels_unary(request)
 
 
-def test_set_labels_rest_from_dict():
-    test_set_labels_rest(request_type=dict)
+def test_set_labels_unary_rest_from_dict():
+    test_set_labels_unary_rest(request_type=dict)
 
 
-def test_set_labels_rest_flattened(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1610,7 +1604,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_labels(**mock_args)
+        client.set_labels_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1623,7 +1617,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_labels_rest_flattened_error(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened_error(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1631,7 +1625,7 @@ def test_set_labels_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_labels(
+        client.set_labels_unary(
             compute.SetLabelsForwardingRuleRequest(),
             project="project_value",
             region="region_value",
@@ -1642,7 +1636,7 @@ def test_set_labels_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_target_rest(
+def test_set_target_unary_rest(
     transport: str = "rest", request_type=compute.SetTargetForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1694,7 +1688,7 @@ def test_set_target_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_target(request)
+        response = client.set_target_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1722,7 +1716,7 @@ def test_set_target_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_target_rest_bad_request(
+def test_set_target_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetTargetForwardingRuleRequest
 ):
     client = ForwardingRulesClient(
@@ -1749,14 +1743,14 @@ def test_set_target_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_target(request)
+        client.set_target_unary(request)
 
 
-def test_set_target_rest_from_dict():
-    test_set_target_rest(request_type=dict)
+def test_set_target_unary_rest_from_dict():
+    test_set_target_unary_rest(request_type=dict)
 
 
-def test_set_target_rest_flattened(transport: str = "rest"):
+def test_set_target_unary_rest_flattened(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1789,7 +1783,7 @@ def test_set_target_rest_flattened(transport: str = "rest"):
             target_reference_resource=compute.TargetReference(target="target_value"),
         )
         mock_args.update(sample_request)
-        client.set_target(**mock_args)
+        client.set_target_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1802,7 +1796,7 @@ def test_set_target_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_target_rest_flattened_error(transport: str = "rest"):
+def test_set_target_unary_rest_flattened_error(transport: str = "rest"):
     client = ForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1810,7 +1804,7 @@ def test_set_target_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_target(
+        client.set_target_unary(
             compute.SetTargetForwardingRuleRequest(),
             project="project_value",
             region="region_value",
