@@ -419,7 +419,7 @@ def test_global_addresses_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteGlobalAddressRequest
 ):
     client = GlobalAddressesClient(
@@ -464,7 +464,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -492,7 +492,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteGlobalAddressRequest
 ):
     client = GlobalAddressesClient(
@@ -512,14 +512,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = GlobalAddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -543,7 +543,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", address="address_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -556,7 +556,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalAddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -564,7 +564,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteGlobalAddressRequest(),
             project="project_value",
             address="address_value",
@@ -587,20 +587,20 @@ def test_get_rest(
         # Designate an appropriate value for the returned response.
         return_value = compute.Address(
             address="address_value",
-            address_type=compute.Address.AddressType.EXTERNAL,
+            address_type="address_type_value",
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             id=205,
-            ip_version=compute.Address.IpVersion.IPV4,
+            ip_version="ip_version_value",
             kind="kind_value",
             name="name_value",
             network="network_value",
-            network_tier=compute.Address.NetworkTier.PREMIUM,
+            network_tier="network_tier_value",
             prefix_length=1391,
-            purpose=compute.Address.Purpose.DNS_RESOLVER,
+            purpose="purpose_value",
             region="region_value",
             self_link="self_link_value",
-            status=compute.Address.Status.IN_USE,
+            status="status_value",
             subnetwork="subnetwork_value",
             users=["users_value"],
         )
@@ -616,20 +616,20 @@ def test_get_rest(
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Address)
     assert response.address == "address_value"
-    assert response.address_type == compute.Address.AddressType.EXTERNAL
+    assert response.address_type == "address_type_value"
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.id == 205
-    assert response.ip_version == compute.Address.IpVersion.IPV4
+    assert response.ip_version == "ip_version_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
-    assert response.network_tier == compute.Address.NetworkTier.PREMIUM
+    assert response.network_tier == "network_tier_value"
     assert response.prefix_length == 1391
-    assert response.purpose == compute.Address.Purpose.DNS_RESOLVER
+    assert response.purpose == "purpose_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
-    assert response.status == compute.Address.Status.IN_USE
+    assert response.status == "status_value"
     assert response.subnetwork == "subnetwork_value"
     assert response.users == ["users_value"]
 
@@ -713,7 +713,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertGlobalAddressRequest
 ):
     client = GlobalAddressesClient(
@@ -759,7 +759,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -787,7 +787,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertGlobalAddressRequest
 ):
     client = GlobalAddressesClient(
@@ -808,14 +808,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = GlobalAddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -842,7 +842,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             address_resource=compute.Address(address="address_value"),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -855,7 +855,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalAddressesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -863,7 +863,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertGlobalAddressRequest(),
             project="project_value",
             address_resource=compute.Address(address="address_value"),
