@@ -440,7 +440,7 @@ def test_global_forwarding_rules_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -485,7 +485,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -513,7 +513,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -533,14 +533,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -566,7 +566,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", forwarding_rule="forwarding_rule_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -579,7 +579,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -587,7 +587,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteGlobalForwardingRuleRequest(),
             project="project_value",
             forwarding_rule="forwarding_rule_value",
@@ -610,7 +610,7 @@ def test_get_rest(
         # Designate an appropriate value for the returned response.
         return_value = compute.ForwardingRule(
             I_p_address="I_p_address_value",
-            I_p_protocol=compute.ForwardingRule.IPProtocol.AH,
+            I_p_protocol="I_p_protocol_value",
             all_ports=True,
             allow_global_access=True,
             backend_service="backend_service_value",
@@ -618,18 +618,18 @@ def test_get_rest(
             description="description_value",
             fingerprint="fingerprint_value",
             id=205,
-            ip_version=compute.ForwardingRule.IpVersion.IPV4,
+            ip_version="ip_version_value",
             is_mirroring_collector=True,
             kind="kind_value",
             label_fingerprint="label_fingerprint_value",
-            load_balancing_scheme=compute.ForwardingRule.LoadBalancingScheme.EXTERNAL,
+            load_balancing_scheme="load_balancing_scheme_value",
             name="name_value",
             network="network_value",
-            network_tier=compute.ForwardingRule.NetworkTier.PREMIUM,
+            network_tier="network_tier_value",
             port_range="port_range_value",
             ports=["ports_value"],
             psc_connection_id=1793,
-            psc_connection_status=compute.ForwardingRule.PscConnectionStatus.ACCEPTED,
+            psc_connection_status="psc_connection_status_value",
             region="region_value",
             self_link="self_link_value",
             service_label="service_label_value",
@@ -649,7 +649,7 @@ def test_get_rest(
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.ForwardingRule)
     assert response.I_p_address == "I_p_address_value"
-    assert response.I_p_protocol == compute.ForwardingRule.IPProtocol.AH
+    assert response.I_p_protocol == "I_p_protocol_value"
     assert response.all_ports is True
     assert response.allow_global_access is True
     assert response.backend_service == "backend_service_value"
@@ -657,24 +657,18 @@ def test_get_rest(
     assert response.description == "description_value"
     assert response.fingerprint == "fingerprint_value"
     assert response.id == 205
-    assert response.ip_version == compute.ForwardingRule.IpVersion.IPV4
+    assert response.ip_version == "ip_version_value"
     assert response.is_mirroring_collector is True
     assert response.kind == "kind_value"
     assert response.label_fingerprint == "label_fingerprint_value"
-    assert (
-        response.load_balancing_scheme
-        == compute.ForwardingRule.LoadBalancingScheme.EXTERNAL
-    )
+    assert response.load_balancing_scheme == "load_balancing_scheme_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
-    assert response.network_tier == compute.ForwardingRule.NetworkTier.PREMIUM
+    assert response.network_tier == "network_tier_value"
     assert response.port_range == "port_range_value"
     assert response.ports == ["ports_value"]
     assert response.psc_connection_id == 1793
-    assert (
-        response.psc_connection_status
-        == compute.ForwardingRule.PscConnectionStatus.ACCEPTED
-    )
+    assert response.psc_connection_status == "psc_connection_status_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.service_label == "service_label_value"
@@ -764,7 +758,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -812,7 +806,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -840,7 +834,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -863,14 +857,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -899,7 +893,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -912,7 +906,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -920,7 +914,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertGlobalForwardingRuleRequest(),
             project="project_value",
             forwarding_rule_resource=compute.ForwardingRule(
@@ -1094,7 +1088,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -1142,7 +1136,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1170,7 +1164,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -1193,14 +1187,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1230,7 +1224,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1243,7 +1237,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1251,7 +1245,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchGlobalForwardingRuleRequest(),
             project="project_value",
             forwarding_rule="forwarding_rule_value",
@@ -1261,7 +1255,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_labels_rest(
+def test_set_labels_unary_rest(
     transport: str = "rest", request_type=compute.SetLabelsGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -1309,7 +1303,7 @@ def test_set_labels_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_labels(request)
+        response = client.set_labels_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1337,7 +1331,7 @@ def test_set_labels_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_labels_rest_bad_request(
+def test_set_labels_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetLabelsGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -1360,14 +1354,14 @@ def test_set_labels_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_labels(request)
+        client.set_labels_unary(request)
 
 
-def test_set_labels_rest_from_dict():
-    test_set_labels_rest(request_type=dict)
+def test_set_labels_unary_rest_from_dict():
+    test_set_labels_unary_rest(request_type=dict)
 
 
-def test_set_labels_rest_flattened(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1397,7 +1391,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_labels(**mock_args)
+        client.set_labels_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1410,7 +1404,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_labels_rest_flattened_error(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1418,7 +1412,7 @@ def test_set_labels_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_labels(
+        client.set_labels_unary(
             compute.SetLabelsGlobalForwardingRuleRequest(),
             project="project_value",
             resource="resource_value",
@@ -1428,7 +1422,7 @@ def test_set_labels_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_target_rest(
+def test_set_target_unary_rest(
     transport: str = "rest", request_type=compute.SetTargetGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -1476,7 +1470,7 @@ def test_set_target_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_target(request)
+        response = client.set_target_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1504,7 +1498,7 @@ def test_set_target_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_target_rest_bad_request(
+def test_set_target_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetTargetGlobalForwardingRuleRequest
 ):
     client = GlobalForwardingRulesClient(
@@ -1527,14 +1521,14 @@ def test_set_target_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_target(request)
+        client.set_target_unary(request)
 
 
-def test_set_target_rest_from_dict():
-    test_set_target_rest(request_type=dict)
+def test_set_target_unary_rest_from_dict():
+    test_set_target_unary_rest(request_type=dict)
 
 
-def test_set_target_rest_flattened(transport: str = "rest"):
+def test_set_target_unary_rest_flattened(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1562,7 +1556,7 @@ def test_set_target_rest_flattened(transport: str = "rest"):
             target_reference_resource=compute.TargetReference(target="target_value"),
         )
         mock_args.update(sample_request)
-        client.set_target(**mock_args)
+        client.set_target_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1575,7 +1569,7 @@ def test_set_target_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_target_rest_flattened_error(transport: str = "rest"):
+def test_set_target_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalForwardingRulesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1583,7 +1577,7 @@ def test_set_target_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_target(
+        client.set_target_unary(
             compute.SetTargetGlobalForwardingRuleRequest(),
             project="project_value",
             forwarding_rule="forwarding_rule_value",
