@@ -446,7 +446,7 @@ def test_global_network_endpoint_groups_client_client_options_credentials_file(
         )
 
 
-def test_attach_network_endpoints_rest(
+def test_attach_network_endpoints_unary_rest(
     transport: str = "rest",
     request_type=compute.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
 ):
@@ -499,7 +499,7 @@ def test_attach_network_endpoints_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.attach_network_endpoints(request)
+        response = client.attach_network_endpoints_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -527,7 +527,7 @@ def test_attach_network_endpoints_rest(
     assert response.zone == "zone_value"
 
 
-def test_attach_network_endpoints_rest_bad_request(
+def test_attach_network_endpoints_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
 ):
@@ -555,14 +555,14 @@ def test_attach_network_endpoints_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.attach_network_endpoints(request)
+        client.attach_network_endpoints_unary(request)
 
 
-def test_attach_network_endpoints_rest_from_dict():
-    test_attach_network_endpoints_rest(request_type=dict)
+def test_attach_network_endpoints_unary_rest_from_dict():
+    test_attach_network_endpoints_unary_rest(request_type=dict)
 
 
-def test_attach_network_endpoints_rest_flattened(transport: str = "rest"):
+def test_attach_network_endpoints_unary_rest_flattened(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -594,7 +594,7 @@ def test_attach_network_endpoints_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.attach_network_endpoints(**mock_args)
+        client.attach_network_endpoints_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -607,7 +607,7 @@ def test_attach_network_endpoints_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_attach_network_endpoints_rest_flattened_error(transport: str = "rest"):
+def test_attach_network_endpoints_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -615,7 +615,7 @@ def test_attach_network_endpoints_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.attach_network_endpoints(
+        client.attach_network_endpoints_unary(
             compute.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest(),
             project="project_value",
             network_endpoint_group="network_endpoint_group_value",
@@ -627,7 +627,7 @@ def test_attach_network_endpoints_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest",
     request_type=compute.DeleteGlobalNetworkEndpointGroupRequest,
 ):
@@ -673,7 +673,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -701,7 +701,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.DeleteGlobalNetworkEndpointGroupRequest,
 ):
@@ -722,14 +722,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -756,7 +756,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             network_endpoint_group="network_endpoint_group_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -769,7 +769,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -777,14 +777,14 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteGlobalNetworkEndpointGroupRequest(),
             project="project_value",
             network_endpoint_group="network_endpoint_group_value",
         )
 
 
-def test_detach_network_endpoints_rest(
+def test_detach_network_endpoints_unary_rest(
     transport: str = "rest",
     request_type=compute.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
 ):
@@ -837,7 +837,7 @@ def test_detach_network_endpoints_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.detach_network_endpoints(request)
+        response = client.detach_network_endpoints_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -865,7 +865,7 @@ def test_detach_network_endpoints_rest(
     assert response.zone == "zone_value"
 
 
-def test_detach_network_endpoints_rest_bad_request(
+def test_detach_network_endpoints_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
 ):
@@ -893,14 +893,14 @@ def test_detach_network_endpoints_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.detach_network_endpoints(request)
+        client.detach_network_endpoints_unary(request)
 
 
-def test_detach_network_endpoints_rest_from_dict():
-    test_detach_network_endpoints_rest(request_type=dict)
+def test_detach_network_endpoints_unary_rest_from_dict():
+    test_detach_network_endpoints_unary_rest(request_type=dict)
 
 
-def test_detach_network_endpoints_rest_flattened(transport: str = "rest"):
+def test_detach_network_endpoints_unary_rest_flattened(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -932,7 +932,7 @@ def test_detach_network_endpoints_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.detach_network_endpoints(**mock_args)
+        client.detach_network_endpoints_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -945,7 +945,7 @@ def test_detach_network_endpoints_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_detach_network_endpoints_rest_flattened_error(transport: str = "rest"):
+def test_detach_network_endpoints_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -953,7 +953,7 @@ def test_detach_network_endpoints_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.detach_network_endpoints(
+        client.detach_network_endpoints_unary(
             compute.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest(),
             project="project_value",
             network_endpoint_group="network_endpoint_group_value",
@@ -987,7 +987,7 @@ def test_get_rest(
             kind="kind_value",
             name="name_value",
             network="network_value",
-            network_endpoint_type=compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP,
+            network_endpoint_type="network_endpoint_type_value",
             region="region_value",
             self_link="self_link_value",
             size=443,
@@ -1012,10 +1012,7 @@ def test_get_rest(
     assert response.kind == "kind_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
-    assert (
-        response.network_endpoint_type
-        == compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP
-    )
+    assert response.network_endpoint_type == "network_endpoint_type_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.size == 443
@@ -1105,7 +1102,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest",
     request_type=compute.InsertGlobalNetworkEndpointGroupRequest,
 ):
@@ -1154,7 +1151,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1182,7 +1179,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.InsertGlobalNetworkEndpointGroupRequest,
 ):
@@ -1206,14 +1203,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1242,7 +1239,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1255,7 +1252,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalNetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1263,7 +1260,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertGlobalNetworkEndpointGroupRequest(),
             project="project_value",
             network_endpoint_group_resource=compute.NetworkEndpointGroup(
