@@ -452,7 +452,7 @@ def test_global_public_delegated_prefixes_client_client_options_credentials_file
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest",
     request_type=compute.DeleteGlobalPublicDelegatedPrefixeRequest,
 ):
@@ -498,7 +498,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -526,7 +526,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.DeleteGlobalPublicDelegatedPrefixeRequest,
 ):
@@ -547,14 +547,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = GlobalPublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -581,7 +581,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             public_delegated_prefix="public_delegated_prefix_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -594,7 +594,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalPublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -602,7 +602,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteGlobalPublicDelegatedPrefixeRequest(),
             project="project_value",
             public_delegated_prefix="public_delegated_prefix_value",
@@ -635,7 +635,7 @@ def test_get_rest(
             parent_prefix="parent_prefix_value",
             region="region_value",
             self_link="self_link_value",
-            status=compute.PublicDelegatedPrefix.Status.ANNOUNCED,
+            status="status_value",
         )
 
         # Wrap the value into a proper Response obj
@@ -659,7 +659,7 @@ def test_get_rest(
     assert response.parent_prefix == "parent_prefix_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
-    assert response.status == compute.PublicDelegatedPrefix.Status.ANNOUNCED
+    assert response.status == "status_value"
 
 
 def test_get_rest_bad_request(
@@ -744,7 +744,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest",
     request_type=compute.InsertGlobalPublicDelegatedPrefixeRequest,
 ):
@@ -793,7 +793,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -821,7 +821,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.InsertGlobalPublicDelegatedPrefixeRequest,
 ):
@@ -845,14 +845,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = GlobalPublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -881,7 +881,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -894,7 +894,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalPublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -902,7 +902,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertGlobalPublicDelegatedPrefixeRequest(),
             project="project_value",
             public_delegated_prefix_resource=compute.PublicDelegatedPrefix(
@@ -1081,7 +1081,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest",
     request_type=compute.PatchGlobalPublicDelegatedPrefixeRequest,
 ):
@@ -1130,7 +1130,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1158,7 +1158,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.PatchGlobalPublicDelegatedPrefixeRequest,
 ):
@@ -1182,14 +1182,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = GlobalPublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1219,7 +1219,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1232,7 +1232,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = GlobalPublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1240,7 +1240,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchGlobalPublicDelegatedPrefixeRequest(),
             project="project_value",
             public_delegated_prefix="public_delegated_prefix_value",
