@@ -583,7 +583,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -628,7 +628,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -656,7 +656,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -676,14 +676,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -707,7 +707,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", health_check="health_check_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -720,7 +720,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -728,7 +728,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteHealthCheckRequest(),
             project="project_value",
             health_check="health_check_value",
@@ -758,7 +758,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetHealthCheckRe
             region="region_value",
             self_link="self_link_value",
             timeout_sec=1185,
-            type_=compute.HealthCheck.Type.GRPC,
+            type_="type__value",
             unhealthy_threshold=2046,
         )
 
@@ -782,7 +782,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetHealthCheckRe
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.timeout_sec == 1185
-    assert response.type_ == compute.HealthCheck.Type.GRPC
+    assert response.type_ == "type__value"
     assert response.unhealthy_threshold == 2046
 
 
@@ -865,7 +865,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -911,7 +911,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -939,7 +939,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -960,14 +960,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -994,7 +994,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             health_check_resource=compute.HealthCheck(check_interval_sec=1884),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1007,7 +1007,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1015,7 +1015,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertHealthCheckRequest(),
             project="project_value",
             health_check_resource=compute.HealthCheck(check_interval_sec=1884),
@@ -1185,7 +1185,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -1231,7 +1231,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1259,7 +1259,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -1280,14 +1280,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1315,7 +1315,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             health_check_resource=compute.HealthCheck(check_interval_sec=1884),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1328,7 +1328,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1336,7 +1336,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchHealthCheckRequest(),
             project="project_value",
             health_check="health_check_value",
@@ -1344,7 +1344,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_update_rest(
+def test_update_unary_rest(
     transport: str = "rest", request_type=compute.UpdateHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -1390,7 +1390,7 @@ def test_update_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1418,7 +1418,7 @@ def test_update_rest(
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateHealthCheckRequest
 ):
     client = HealthChecksClient(
@@ -1439,14 +1439,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1474,7 +1474,7 @@ def test_update_rest_flattened(transport: str = "rest"):
             health_check_resource=compute.HealthCheck(check_interval_sec=1884),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1487,7 +1487,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = HealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1495,7 +1495,7 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateHealthCheckRequest(),
             project="project_value",
             health_check="health_check_value",
