@@ -409,7 +409,7 @@ def test_instance_groups_client_client_options_credentials_file(
         )
 
 
-def test_add_instances_rest(
+def test_add_instances_unary_rest(
     transport: str = "rest", request_type=compute.AddInstancesInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -463,7 +463,7 @@ def test_add_instances_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.add_instances(request)
+        response = client.add_instances_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -491,7 +491,7 @@ def test_add_instances_rest(
     assert response.zone == "zone_value"
 
 
-def test_add_instances_rest_bad_request(
+def test_add_instances_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.AddInstancesInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -520,14 +520,14 @@ def test_add_instances_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.add_instances(request)
+        client.add_instances_unary(request)
 
 
-def test_add_instances_rest_from_dict():
-    test_add_instances_rest(request_type=dict)
+def test_add_instances_unary_rest_from_dict():
+    test_add_instances_unary_rest(request_type=dict)
 
 
-def test_add_instances_rest_flattened(transport: str = "rest"):
+def test_add_instances_unary_rest_flattened(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -562,7 +562,7 @@ def test_add_instances_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.add_instances(**mock_args)
+        client.add_instances_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -575,7 +575,7 @@ def test_add_instances_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_add_instances_rest_flattened_error(transport: str = "rest"):
+def test_add_instances_unary_rest_flattened_error(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -583,7 +583,7 @@ def test_add_instances_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.add_instances(
+        client.add_instances_unary(
             compute.AddInstancesInstanceGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -776,7 +776,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -825,7 +825,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -853,7 +853,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -877,14 +877,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -916,7 +916,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             instance_group="instance_group_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -929,7 +929,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -937,7 +937,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteInstanceGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -1094,7 +1094,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -1142,7 +1142,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1170,7 +1170,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -1193,14 +1193,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1230,7 +1230,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1243,7 +1243,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1251,7 +1251,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertInstanceGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -1442,7 +1442,7 @@ def test_list_instances_rest(
     request_init[
         "instance_groups_list_instances_request_resource"
     ] = compute.InstanceGroupsListInstancesRequest(
-        instance_state=compute.InstanceGroupsListInstancesRequest.InstanceState.ALL
+        instance_state="instance_state_value"
     )
     request = request_type(request_init)
 
@@ -1488,7 +1488,7 @@ def test_list_instances_rest_bad_request(
     request_init[
         "instance_groups_list_instances_request_resource"
     ] = compute.InstanceGroupsListInstancesRequest(
-        instance_state=compute.InstanceGroupsListInstancesRequest.InstanceState.ALL
+        instance_state="instance_state_value"
     )
     request = request_type(request_init)
 
@@ -1539,7 +1539,7 @@ def test_list_instances_rest_flattened(transport: str = "rest"):
             zone="zone_value",
             instance_group="instance_group_value",
             instance_groups_list_instances_request_resource=compute.InstanceGroupsListInstancesRequest(
-                instance_state=compute.InstanceGroupsListInstancesRequest.InstanceState.ALL
+                instance_state="instance_state_value"
             ),
         )
         mock_args.update(sample_request)
@@ -1570,7 +1570,7 @@ def test_list_instances_rest_flattened_error(transport: str = "rest"):
             zone="zone_value",
             instance_group="instance_group_value",
             instance_groups_list_instances_request_resource=compute.InstanceGroupsListInstancesRequest(
-                instance_state=compute.InstanceGroupsListInstancesRequest.InstanceState.ALL
+                instance_state="instance_state_value"
             ),
         )
 
@@ -1624,7 +1624,7 @@ def test_list_instances_rest_pager():
         sample_request[
             "instance_groups_list_instances_request_resource"
         ] = compute.InstanceGroupsListInstancesRequest(
-            instance_state=compute.InstanceGroupsListInstancesRequest.InstanceState.ALL
+            instance_state="instance_state_value"
         )
 
         pager = client.list_instances(request=sample_request)
@@ -1638,7 +1638,7 @@ def test_list_instances_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_remove_instances_rest(
+def test_remove_instances_unary_rest(
     transport: str = "rest", request_type=compute.RemoveInstancesInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -1692,7 +1692,7 @@ def test_remove_instances_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.remove_instances(request)
+        response = client.remove_instances_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1720,7 +1720,7 @@ def test_remove_instances_rest(
     assert response.zone == "zone_value"
 
 
-def test_remove_instances_rest_bad_request(
+def test_remove_instances_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.RemoveInstancesInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -1749,14 +1749,14 @@ def test_remove_instances_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.remove_instances(request)
+        client.remove_instances_unary(request)
 
 
-def test_remove_instances_rest_from_dict():
-    test_remove_instances_rest(request_type=dict)
+def test_remove_instances_unary_rest_from_dict():
+    test_remove_instances_unary_rest(request_type=dict)
 
 
-def test_remove_instances_rest_flattened(transport: str = "rest"):
+def test_remove_instances_unary_rest_flattened(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1791,7 +1791,7 @@ def test_remove_instances_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.remove_instances(**mock_args)
+        client.remove_instances_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1804,7 +1804,7 @@ def test_remove_instances_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_remove_instances_rest_flattened_error(transport: str = "rest"):
+def test_remove_instances_unary_rest_flattened_error(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1812,7 +1812,7 @@ def test_remove_instances_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.remove_instances(
+        client.remove_instances_unary(
             compute.RemoveInstancesInstanceGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -1823,7 +1823,7 @@ def test_remove_instances_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_named_ports_rest(
+def test_set_named_ports_unary_rest(
     transport: str = "rest", request_type=compute.SetNamedPortsInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -1875,7 +1875,7 @@ def test_set_named_ports_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_named_ports(request)
+        response = client.set_named_ports_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1903,7 +1903,7 @@ def test_set_named_ports_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_named_ports_rest_bad_request(
+def test_set_named_ports_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetNamedPortsInstanceGroupRequest
 ):
     client = InstanceGroupsClient(
@@ -1930,14 +1930,14 @@ def test_set_named_ports_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_named_ports(request)
+        client.set_named_ports_unary(request)
 
 
-def test_set_named_ports_rest_from_dict():
-    test_set_named_ports_rest(request_type=dict)
+def test_set_named_ports_unary_rest_from_dict():
+    test_set_named_ports_unary_rest(request_type=dict)
 
 
-def test_set_named_ports_rest_flattened(transport: str = "rest"):
+def test_set_named_ports_unary_rest_flattened(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1972,7 +1972,7 @@ def test_set_named_ports_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_named_ports(**mock_args)
+        client.set_named_ports_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1985,7 +1985,7 @@ def test_set_named_ports_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_named_ports_rest_flattened_error(transport: str = "rest"):
+def test_set_named_ports_unary_rest_flattened_error(transport: str = "rest"):
     client = InstanceGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1993,7 +1993,7 @@ def test_set_named_ports_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_named_ports(
+        client.set_named_ports_unary(
             compute.SetNamedPortsInstanceGroupRequest(),
             project="project_value",
             zone="zone_value",
