@@ -634,7 +634,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteInterconnectAttachmentRequest
 ):
     client = InterconnectAttachmentsClient(
@@ -683,7 +683,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -711,7 +711,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteInterconnectAttachmentRequest
 ):
     client = InterconnectAttachmentsClient(
@@ -735,14 +735,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = InterconnectAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -774,7 +774,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             interconnect_attachment="interconnect_attachment_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -787,7 +787,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = InterconnectAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -795,7 +795,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteInterconnectAttachmentRequest(),
             project="project_value",
             region="region_value",
@@ -823,15 +823,15 @@ def test_get_rest(
         # Designate an appropriate value for the returned response.
         return_value = compute.InterconnectAttachment(
             admin_enabled=True,
-            bandwidth=compute.InterconnectAttachment.Bandwidth.BPS_100M,
+            bandwidth="bandwidth_value",
             candidate_subnets=["candidate_subnets_value"],
             cloud_router_ip_address="cloud_router_ip_address_value",
             creation_timestamp="creation_timestamp_value",
             customer_router_ip_address="customer_router_ip_address_value",
             dataplane_version=1807,
             description="description_value",
-            edge_availability_domain=compute.InterconnectAttachment.EdgeAvailabilityDomain.AVAILABILITY_DOMAIN_1,
-            encryption=compute.InterconnectAttachment.Encryption.IPSEC,
+            edge_availability_domain="edge_availability_domain_value",
+            encryption="encryption_value",
             google_reference_id="google_reference_id_value",
             id=205,
             interconnect="interconnect_value",
@@ -839,15 +839,15 @@ def test_get_rest(
             kind="kind_value",
             mtu=342,
             name="name_value",
-            operational_status=compute.InterconnectAttachment.OperationalStatus.OS_ACTIVE,
+            operational_status="operational_status_value",
             pairing_key="pairing_key_value",
             partner_asn=1181,
             region="region_value",
             router="router_value",
             satisfies_pzs=True,
             self_link="self_link_value",
-            state=compute.InterconnectAttachment.State.ACTIVE,
-            type_=compute.InterconnectAttachment.Type.DEDICATED,
+            state="state_value",
+            type_="type__value",
             vlan_tag8021q=1160,
         )
 
@@ -862,18 +862,15 @@ def test_get_rest(
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.InterconnectAttachment)
     assert response.admin_enabled is True
-    assert response.bandwidth == compute.InterconnectAttachment.Bandwidth.BPS_100M
+    assert response.bandwidth == "bandwidth_value"
     assert response.candidate_subnets == ["candidate_subnets_value"]
     assert response.cloud_router_ip_address == "cloud_router_ip_address_value"
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.customer_router_ip_address == "customer_router_ip_address_value"
     assert response.dataplane_version == 1807
     assert response.description == "description_value"
-    assert (
-        response.edge_availability_domain
-        == compute.InterconnectAttachment.EdgeAvailabilityDomain.AVAILABILITY_DOMAIN_1
-    )
-    assert response.encryption == compute.InterconnectAttachment.Encryption.IPSEC
+    assert response.edge_availability_domain == "edge_availability_domain_value"
+    assert response.encryption == "encryption_value"
     assert response.google_reference_id == "google_reference_id_value"
     assert response.id == 205
     assert response.interconnect == "interconnect_value"
@@ -881,18 +878,15 @@ def test_get_rest(
     assert response.kind == "kind_value"
     assert response.mtu == 342
     assert response.name == "name_value"
-    assert (
-        response.operational_status
-        == compute.InterconnectAttachment.OperationalStatus.OS_ACTIVE
-    )
+    assert response.operational_status == "operational_status_value"
     assert response.pairing_key == "pairing_key_value"
     assert response.partner_asn == 1181
     assert response.region == "region_value"
     assert response.router == "router_value"
     assert response.satisfies_pzs is True
     assert response.self_link == "self_link_value"
-    assert response.state == compute.InterconnectAttachment.State.ACTIVE
-    assert response.type_ == compute.InterconnectAttachment.Type.DEDICATED
+    assert response.state == "state_value"
+    assert response.type_ == "type__value"
     assert response.vlan_tag8021q == 1160
 
 
@@ -988,7 +982,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertInterconnectAttachmentRequest
 ):
     client = InterconnectAttachmentsClient(
@@ -1036,7 +1030,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1064,7 +1058,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertInterconnectAttachmentRequest
 ):
     client = InterconnectAttachmentsClient(
@@ -1087,14 +1081,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = InterconnectAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1124,7 +1118,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1137,7 +1131,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = InterconnectAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1145,7 +1139,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertInterconnectAttachmentRequest(),
             project="project_value",
             region="region_value",
@@ -1327,7 +1321,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchInterconnectAttachmentRequest
 ):
     client = InterconnectAttachmentsClient(
@@ -1379,7 +1373,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1407,7 +1401,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchInterconnectAttachmentRequest
 ):
     client = InterconnectAttachmentsClient(
@@ -1434,14 +1428,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = InterconnectAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1476,7 +1470,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1489,7 +1483,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = InterconnectAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1497,7 +1491,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchInterconnectAttachmentRequest(),
             project="project_value",
             region="region_value",
