@@ -408,7 +408,7 @@ def test_interconnects_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteInterconnectRequest
 ):
     client = InterconnectsClient(
@@ -453,7 +453,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -481,7 +481,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteInterconnectRequest
 ):
     client = InterconnectsClient(
@@ -501,14 +501,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = InterconnectsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -532,7 +532,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", interconnect="interconnect_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -545,7 +545,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = InterconnectsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -553,7 +553,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteInterconnectRequest(),
             project="project_value",
             interconnect="interconnect_value",
@@ -581,19 +581,19 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetInterconnectR
             google_reference_id="google_reference_id_value",
             id=205,
             interconnect_attachments=["interconnect_attachments_value"],
-            interconnect_type=compute.Interconnect.InterconnectType.DEDICATED,
+            interconnect_type="interconnect_type_value",
             kind="kind_value",
-            link_type=compute.Interconnect.LinkType.LINK_TYPE_ETHERNET_100G_LR,
+            link_type="link_type_value",
             location="location_value",
             name="name_value",
             noc_contact_email="noc_contact_email_value",
-            operational_status=compute.Interconnect.OperationalStatus.OS_ACTIVE,
+            operational_status="operational_status_value",
             peer_ip_address="peer_ip_address_value",
             provisioned_link_count=2375,
             requested_link_count=2151,
             satisfies_pzs=True,
             self_link="self_link_value",
-            state=compute.Interconnect.State.ACTIVE,
+            state="state_value",
         )
 
         # Wrap the value into a proper Response obj
@@ -614,23 +614,19 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetInterconnectR
     assert response.google_reference_id == "google_reference_id_value"
     assert response.id == 205
     assert response.interconnect_attachments == ["interconnect_attachments_value"]
-    assert response.interconnect_type == compute.Interconnect.InterconnectType.DEDICATED
+    assert response.interconnect_type == "interconnect_type_value"
     assert response.kind == "kind_value"
-    assert (
-        response.link_type == compute.Interconnect.LinkType.LINK_TYPE_ETHERNET_100G_LR
-    )
+    assert response.link_type == "link_type_value"
     assert response.location == "location_value"
     assert response.name == "name_value"
     assert response.noc_contact_email == "noc_contact_email_value"
-    assert (
-        response.operational_status == compute.Interconnect.OperationalStatus.OS_ACTIVE
-    )
+    assert response.operational_status == "operational_status_value"
     assert response.peer_ip_address == "peer_ip_address_value"
     assert response.provisioned_link_count == 2375
     assert response.requested_link_count == 2151
     assert response.satisfies_pzs is True
     assert response.self_link == "self_link_value"
-    assert response.state == compute.Interconnect.State.ACTIVE
+    assert response.state == "state_value"
 
 
 def test_get_rest_bad_request(
@@ -823,7 +819,7 @@ def test_get_diagnostics_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertInterconnectRequest
 ):
     client = InterconnectsClient(
@@ -869,7 +865,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -897,7 +893,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertInterconnectRequest
 ):
     client = InterconnectsClient(
@@ -918,14 +914,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = InterconnectsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -952,7 +948,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             interconnect_resource=compute.Interconnect(admin_enabled=True),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -965,7 +961,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = InterconnectsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -973,7 +969,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertInterconnectRequest(),
             project="project_value",
             interconnect_resource=compute.Interconnect(admin_enabled=True),
@@ -1143,7 +1139,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchInterconnectRequest
 ):
     client = InterconnectsClient(
@@ -1189,7 +1185,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1217,7 +1213,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchInterconnectRequest
 ):
     client = InterconnectsClient(
@@ -1238,14 +1234,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = InterconnectsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1273,7 +1269,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             interconnect_resource=compute.Interconnect(admin_enabled=True),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1286,7 +1282,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = InterconnectsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1294,7 +1290,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchInterconnectRequest(),
             project="project_value",
             interconnect="interconnect_value",
