@@ -634,7 +634,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_attach_network_endpoints_rest(
+def test_attach_network_endpoints_unary_rest(
     transport: str = "rest",
     request_type=compute.AttachNetworkEndpointsNetworkEndpointGroupRequest,
 ):
@@ -691,7 +691,7 @@ def test_attach_network_endpoints_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.attach_network_endpoints(request)
+        response = client.attach_network_endpoints_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -719,7 +719,7 @@ def test_attach_network_endpoints_rest(
     assert response.zone == "zone_value"
 
 
-def test_attach_network_endpoints_rest_bad_request(
+def test_attach_network_endpoints_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.AttachNetworkEndpointsNetworkEndpointGroupRequest,
 ):
@@ -751,14 +751,14 @@ def test_attach_network_endpoints_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.attach_network_endpoints(request)
+        client.attach_network_endpoints_unary(request)
 
 
-def test_attach_network_endpoints_rest_from_dict():
-    test_attach_network_endpoints_rest(request_type=dict)
+def test_attach_network_endpoints_unary_rest_from_dict():
+    test_attach_network_endpoints_unary_rest(request_type=dict)
 
 
-def test_attach_network_endpoints_rest_flattened(transport: str = "rest"):
+def test_attach_network_endpoints_unary_rest_flattened(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -795,7 +795,7 @@ def test_attach_network_endpoints_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.attach_network_endpoints(**mock_args)
+        client.attach_network_endpoints_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -808,7 +808,7 @@ def test_attach_network_endpoints_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_attach_network_endpoints_rest_flattened_error(transport: str = "rest"):
+def test_attach_network_endpoints_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -816,7 +816,7 @@ def test_attach_network_endpoints_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.attach_network_endpoints(
+        client.attach_network_endpoints_unary(
             compute.AttachNetworkEndpointsNetworkEndpointGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -829,7 +829,7 @@ def test_attach_network_endpoints_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteNetworkEndpointGroupRequest
 ):
     client = NetworkEndpointGroupsClient(
@@ -878,7 +878,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -906,7 +906,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteNetworkEndpointGroupRequest
 ):
     client = NetworkEndpointGroupsClient(
@@ -930,14 +930,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -969,7 +969,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             network_endpoint_group="network_endpoint_group_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -982,7 +982,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -990,7 +990,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteNetworkEndpointGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -998,7 +998,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_detach_network_endpoints_rest(
+def test_detach_network_endpoints_unary_rest(
     transport: str = "rest",
     request_type=compute.DetachNetworkEndpointsNetworkEndpointGroupRequest,
 ):
@@ -1055,7 +1055,7 @@ def test_detach_network_endpoints_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.detach_network_endpoints(request)
+        response = client.detach_network_endpoints_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1083,7 +1083,7 @@ def test_detach_network_endpoints_rest(
     assert response.zone == "zone_value"
 
 
-def test_detach_network_endpoints_rest_bad_request(
+def test_detach_network_endpoints_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.DetachNetworkEndpointsNetworkEndpointGroupRequest,
 ):
@@ -1115,14 +1115,14 @@ def test_detach_network_endpoints_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.detach_network_endpoints(request)
+        client.detach_network_endpoints_unary(request)
 
 
-def test_detach_network_endpoints_rest_from_dict():
-    test_detach_network_endpoints_rest(request_type=dict)
+def test_detach_network_endpoints_unary_rest_from_dict():
+    test_detach_network_endpoints_unary_rest(request_type=dict)
 
 
-def test_detach_network_endpoints_rest_flattened(transport: str = "rest"):
+def test_detach_network_endpoints_unary_rest_flattened(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1159,7 +1159,7 @@ def test_detach_network_endpoints_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.detach_network_endpoints(**mock_args)
+        client.detach_network_endpoints_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1172,7 +1172,7 @@ def test_detach_network_endpoints_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_detach_network_endpoints_rest_flattened_error(transport: str = "rest"):
+def test_detach_network_endpoints_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1180,7 +1180,7 @@ def test_detach_network_endpoints_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.detach_network_endpoints(
+        client.detach_network_endpoints_unary(
             compute.DetachNetworkEndpointsNetworkEndpointGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -1219,7 +1219,7 @@ def test_get_rest(
             kind="kind_value",
             name="name_value",
             network="network_value",
-            network_endpoint_type=compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP,
+            network_endpoint_type="network_endpoint_type_value",
             region="region_value",
             self_link="self_link_value",
             size=443,
@@ -1244,10 +1244,7 @@ def test_get_rest(
     assert response.kind == "kind_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
-    assert (
-        response.network_endpoint_type
-        == compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP
-    )
+    assert response.network_endpoint_type == "network_endpoint_type_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.size == 443
@@ -1347,7 +1344,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertNetworkEndpointGroupRequest
 ):
     client = NetworkEndpointGroupsClient(
@@ -1395,7 +1392,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1423,7 +1420,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertNetworkEndpointGroupRequest
 ):
     client = NetworkEndpointGroupsClient(
@@ -1446,14 +1443,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1483,7 +1480,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1496,7 +1493,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworkEndpointGroupsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1504,7 +1501,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertNetworkEndpointGroupRequest(),
             project="project_value",
             zone="zone_value",
@@ -1698,7 +1695,7 @@ def test_list_network_endpoints_rest(
     request_init[
         "network_endpoint_groups_list_endpoints_request_resource"
     ] = compute.NetworkEndpointGroupsListEndpointsRequest(
-        health_status=compute.NetworkEndpointGroupsListEndpointsRequest.HealthStatus.SHOW
+        health_status="health_status_value"
     )
     request = request_type(request_init)
 
@@ -1743,7 +1740,7 @@ def test_list_network_endpoints_rest_bad_request(
     request_init[
         "network_endpoint_groups_list_endpoints_request_resource"
     ] = compute.NetworkEndpointGroupsListEndpointsRequest(
-        health_status=compute.NetworkEndpointGroupsListEndpointsRequest.HealthStatus.SHOW
+        health_status="health_status_value"
     )
     request = request_type(request_init)
 
@@ -1796,7 +1793,7 @@ def test_list_network_endpoints_rest_flattened(transport: str = "rest"):
             zone="zone_value",
             network_endpoint_group="network_endpoint_group_value",
             network_endpoint_groups_list_endpoints_request_resource=compute.NetworkEndpointGroupsListEndpointsRequest(
-                health_status=compute.NetworkEndpointGroupsListEndpointsRequest.HealthStatus.SHOW
+                health_status="health_status_value"
             ),
         )
         mock_args.update(sample_request)
@@ -1827,7 +1824,7 @@ def test_list_network_endpoints_rest_flattened_error(transport: str = "rest"):
             zone="zone_value",
             network_endpoint_group="network_endpoint_group_value",
             network_endpoint_groups_list_endpoints_request_resource=compute.NetworkEndpointGroupsListEndpointsRequest(
-                health_status=compute.NetworkEndpointGroupsListEndpointsRequest.HealthStatus.SHOW
+                health_status="health_status_value"
             ),
         )
 
@@ -1887,7 +1884,7 @@ def test_list_network_endpoints_rest_pager():
         sample_request[
             "network_endpoint_groups_list_endpoints_request_resource"
         ] = compute.NetworkEndpointGroupsListEndpointsRequest(
-            health_status=compute.NetworkEndpointGroupsListEndpointsRequest.HealthStatus.SHOW
+            health_status="health_status_value"
         )
 
         pager = client.list_network_endpoints(request=sample_request)
