@@ -397,7 +397,7 @@ def test_networks_client_client_options_credentials_file(
         )
 
 
-def test_add_peering_rest(
+def test_add_peering_unary_rest(
     transport: str = "rest", request_type=compute.AddPeeringNetworkRequest
 ):
     client = NetworksClient(
@@ -445,7 +445,7 @@ def test_add_peering_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.add_peering(request)
+        response = client.add_peering_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -473,7 +473,7 @@ def test_add_peering_rest(
     assert response.zone == "zone_value"
 
 
-def test_add_peering_rest_bad_request(
+def test_add_peering_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.AddPeeringNetworkRequest
 ):
     client = NetworksClient(
@@ -496,14 +496,14 @@ def test_add_peering_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.add_peering(request)
+        client.add_peering_unary(request)
 
 
-def test_add_peering_rest_from_dict():
-    test_add_peering_rest(request_type=dict)
+def test_add_peering_unary_rest_from_dict():
+    test_add_peering_unary_rest(request_type=dict)
 
 
-def test_add_peering_rest_flattened(transport: str = "rest"):
+def test_add_peering_unary_rest_flattened(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -533,7 +533,7 @@ def test_add_peering_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.add_peering(**mock_args)
+        client.add_peering_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -546,7 +546,7 @@ def test_add_peering_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_add_peering_rest_flattened_error(transport: str = "rest"):
+def test_add_peering_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -554,7 +554,7 @@ def test_add_peering_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.add_peering(
+        client.add_peering_unary(
             compute.AddPeeringNetworkRequest(),
             project="project_value",
             network="network_value",
@@ -564,7 +564,7 @@ def test_add_peering_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteNetworkRequest
 ):
     client = NetworksClient(
@@ -609,7 +609,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -637,7 +637,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteNetworkRequest
 ):
     client = NetworksClient(
@@ -657,14 +657,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -688,7 +688,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", network="network_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -701,7 +701,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -709,7 +709,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteNetworkRequest(),
             project="project_value",
             network="network_value",
@@ -955,7 +955,7 @@ def test_get_effective_firewalls_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertNetworkRequest
 ):
     client = NetworksClient(
@@ -1001,7 +1001,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1029,7 +1029,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertNetworkRequest
 ):
     client = NetworksClient(
@@ -1050,14 +1050,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1084,7 +1084,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             network_resource=compute.Network(I_pv4_range="I_pv4_range_value"),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1097,7 +1097,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1105,7 +1105,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertNetworkRequest(),
             project="project_value",
             network_resource=compute.Network(I_pv4_range="I_pv4_range_value"),
@@ -1435,7 +1435,9 @@ def test_list_peering_routes_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(transport: str = "rest", request_type=compute.PatchNetworkRequest):
+def test_patch_unary_rest(
+    transport: str = "rest", request_type=compute.PatchNetworkRequest
+):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1479,7 +1481,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchNetworkRe
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1507,7 +1509,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchNetworkRe
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchNetworkRequest
 ):
     client = NetworksClient(
@@ -1528,14 +1530,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1563,7 +1565,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             network_resource=compute.Network(I_pv4_range="I_pv4_range_value"),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1576,7 +1578,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1584,7 +1586,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchNetworkRequest(),
             project="project_value",
             network="network_value",
@@ -1592,7 +1594,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_remove_peering_rest(
+def test_remove_peering_unary_rest(
     transport: str = "rest", request_type=compute.RemovePeeringNetworkRequest
 ):
     client = NetworksClient(
@@ -1640,7 +1642,7 @@ def test_remove_peering_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.remove_peering(request)
+        response = client.remove_peering_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1668,7 +1670,7 @@ def test_remove_peering_rest(
     assert response.zone == "zone_value"
 
 
-def test_remove_peering_rest_bad_request(
+def test_remove_peering_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.RemovePeeringNetworkRequest
 ):
     client = NetworksClient(
@@ -1691,14 +1693,14 @@ def test_remove_peering_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.remove_peering(request)
+        client.remove_peering_unary(request)
 
 
-def test_remove_peering_rest_from_dict():
-    test_remove_peering_rest(request_type=dict)
+def test_remove_peering_unary_rest_from_dict():
+    test_remove_peering_unary_rest(request_type=dict)
 
 
-def test_remove_peering_rest_flattened(transport: str = "rest"):
+def test_remove_peering_unary_rest_flattened(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1728,7 +1730,7 @@ def test_remove_peering_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.remove_peering(**mock_args)
+        client.remove_peering_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1741,7 +1743,7 @@ def test_remove_peering_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_remove_peering_rest_flattened_error(transport: str = "rest"):
+def test_remove_peering_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1749,7 +1751,7 @@ def test_remove_peering_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.remove_peering(
+        client.remove_peering_unary(
             compute.RemovePeeringNetworkRequest(),
             project="project_value",
             network="network_value",
@@ -1759,7 +1761,7 @@ def test_remove_peering_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_switch_to_custom_mode_rest(
+def test_switch_to_custom_mode_unary_rest(
     transport: str = "rest", request_type=compute.SwitchToCustomModeNetworkRequest
 ):
     client = NetworksClient(
@@ -1804,7 +1806,7 @@ def test_switch_to_custom_mode_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.switch_to_custom_mode(request)
+        response = client.switch_to_custom_mode_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1832,7 +1834,7 @@ def test_switch_to_custom_mode_rest(
     assert response.zone == "zone_value"
 
 
-def test_switch_to_custom_mode_rest_bad_request(
+def test_switch_to_custom_mode_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SwitchToCustomModeNetworkRequest
 ):
     client = NetworksClient(
@@ -1852,14 +1854,14 @@ def test_switch_to_custom_mode_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.switch_to_custom_mode(request)
+        client.switch_to_custom_mode_unary(request)
 
 
-def test_switch_to_custom_mode_rest_from_dict():
-    test_switch_to_custom_mode_rest(request_type=dict)
+def test_switch_to_custom_mode_unary_rest_from_dict():
+    test_switch_to_custom_mode_unary_rest(request_type=dict)
 
 
-def test_switch_to_custom_mode_rest_flattened(transport: str = "rest"):
+def test_switch_to_custom_mode_unary_rest_flattened(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1883,7 +1885,7 @@ def test_switch_to_custom_mode_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", network="network_value",)
         mock_args.update(sample_request)
-        client.switch_to_custom_mode(**mock_args)
+        client.switch_to_custom_mode_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1896,7 +1898,7 @@ def test_switch_to_custom_mode_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_switch_to_custom_mode_rest_flattened_error(transport: str = "rest"):
+def test_switch_to_custom_mode_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1904,14 +1906,14 @@ def test_switch_to_custom_mode_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.switch_to_custom_mode(
+        client.switch_to_custom_mode_unary(
             compute.SwitchToCustomModeNetworkRequest(),
             project="project_value",
             network="network_value",
         )
 
 
-def test_update_peering_rest(
+def test_update_peering_unary_rest(
     transport: str = "rest", request_type=compute.UpdatePeeringNetworkRequest
 ):
     client = NetworksClient(
@@ -1961,7 +1963,7 @@ def test_update_peering_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update_peering(request)
+        response = client.update_peering_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1989,7 +1991,7 @@ def test_update_peering_rest(
     assert response.zone == "zone_value"
 
 
-def test_update_peering_rest_bad_request(
+def test_update_peering_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdatePeeringNetworkRequest
 ):
     client = NetworksClient(
@@ -2014,14 +2016,14 @@ def test_update_peering_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update_peering(request)
+        client.update_peering_unary(request)
 
 
-def test_update_peering_rest_from_dict():
-    test_update_peering_rest(request_type=dict)
+def test_update_peering_unary_rest_from_dict():
+    test_update_peering_unary_rest(request_type=dict)
 
 
-def test_update_peering_rest_flattened(transport: str = "rest"):
+def test_update_peering_unary_rest_flattened(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2051,7 +2053,7 @@ def test_update_peering_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.update_peering(**mock_args)
+        client.update_peering_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -2064,7 +2066,7 @@ def test_update_peering_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_peering_rest_flattened_error(transport: str = "rest"):
+def test_update_peering_unary_rest_flattened_error(transport: str = "rest"):
     client = NetworksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2072,7 +2074,7 @@ def test_update_peering_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update_peering(
+        client.update_peering_unary(
             compute.UpdatePeeringNetworkRequest(),
             project="project_value",
             network="network_value",
