@@ -590,7 +590,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteNodeTemplateRequest
 ):
     client = NodeTemplatesClient(
@@ -639,7 +639,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -667,7 +667,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteNodeTemplateRequest
 ):
     client = NodeTemplatesClient(
@@ -691,14 +691,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = NodeTemplatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -730,7 +730,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             node_template="node_template_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -743,7 +743,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = NodeTemplatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -751,7 +751,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteNodeTemplateRequest(),
             project="project_value",
             region="region_value",
@@ -776,7 +776,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetNodeTemplateR
     with mock.patch.object(Session, "request") as req:
         # Designate an appropriate value for the returned response.
         return_value = compute.NodeTemplate(
-            cpu_overcommit_type=compute.NodeTemplate.CpuOvercommitType.CPU_OVERCOMMIT_TYPE_UNSPECIFIED,
+            cpu_overcommit_type="cpu_overcommit_type_value",
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             id=205,
@@ -785,7 +785,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetNodeTemplateR
             node_type="node_type_value",
             region="region_value",
             self_link="self_link_value",
-            status=compute.NodeTemplate.Status.CREATING,
+            status="status_value",
             status_message="status_message_value",
         )
 
@@ -799,10 +799,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetNodeTemplateR
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.NodeTemplate)
-    assert (
-        response.cpu_overcommit_type
-        == compute.NodeTemplate.CpuOvercommitType.CPU_OVERCOMMIT_TYPE_UNSPECIFIED
-    )
+    assert response.cpu_overcommit_type == "cpu_overcommit_type_value"
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.id == 205
@@ -811,7 +808,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetNodeTemplateR
     assert response.node_type == "node_type_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
-    assert response.status == compute.NodeTemplate.Status.CREATING
+    assert response.status == "status_value"
     assert response.status_message == "status_message_value"
 
 
@@ -1024,7 +1021,7 @@ def test_get_iam_policy_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertNodeTemplateRequest
 ):
     client = NodeTemplatesClient(
@@ -1072,7 +1069,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1100,7 +1097,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertNodeTemplateRequest
 ):
     client = NodeTemplatesClient(
@@ -1123,14 +1120,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = NodeTemplatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1160,7 +1157,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1173,7 +1170,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = NodeTemplatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1181,7 +1178,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertNodeTemplateRequest(),
             project="project_value",
             region="region_value",
