@@ -444,7 +444,7 @@ def test_public_advertised_prefixes_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeletePublicAdvertisedPrefixeRequest
 ):
     client = PublicAdvertisedPrefixesClient(
@@ -489,7 +489,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -517,7 +517,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeletePublicAdvertisedPrefixeRequest
 ):
     client = PublicAdvertisedPrefixesClient(
@@ -537,14 +537,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = PublicAdvertisedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -571,7 +571,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             public_advertised_prefix="public_advertised_prefix_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -584,7 +584,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = PublicAdvertisedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -592,7 +592,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeletePublicAdvertisedPrefixeRequest(),
             project="project_value",
             public_advertised_prefix="public_advertised_prefix_value",
@@ -624,7 +624,7 @@ def test_get_rest(
             name="name_value",
             self_link="self_link_value",
             shared_secret="shared_secret_value",
-            status=compute.PublicAdvertisedPrefix.Status.INITIAL,
+            status="status_value",
         )
 
         # Wrap the value into a proper Response obj
@@ -647,7 +647,7 @@ def test_get_rest(
     assert response.name == "name_value"
     assert response.self_link == "self_link_value"
     assert response.shared_secret == "shared_secret_value"
-    assert response.status == compute.PublicAdvertisedPrefix.Status.INITIAL
+    assert response.status == "status_value"
 
 
 def test_get_rest_bad_request(
@@ -732,7 +732,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertPublicAdvertisedPrefixeRequest
 ):
     client = PublicAdvertisedPrefixesClient(
@@ -780,7 +780,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -808,7 +808,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertPublicAdvertisedPrefixeRequest
 ):
     client = PublicAdvertisedPrefixesClient(
@@ -831,14 +831,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = PublicAdvertisedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -867,7 +867,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -880,7 +880,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = PublicAdvertisedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -888,7 +888,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertPublicAdvertisedPrefixeRequest(),
             project="project_value",
             public_advertised_prefix_resource=compute.PublicAdvertisedPrefix(
@@ -1067,7 +1067,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchPublicAdvertisedPrefixeRequest
 ):
     client = PublicAdvertisedPrefixesClient(
@@ -1115,7 +1115,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1143,7 +1143,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchPublicAdvertisedPrefixeRequest
 ):
     client = PublicAdvertisedPrefixesClient(
@@ -1166,14 +1166,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = PublicAdvertisedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1203,7 +1203,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1216,7 +1216,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = PublicAdvertisedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1224,7 +1224,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchPublicAdvertisedPrefixeRequest(),
             project="project_value",
             public_advertised_prefix="public_advertised_prefix_value",
