@@ -634,7 +634,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeletePublicDelegatedPrefixeRequest
 ):
     client = PublicDelegatedPrefixesClient(
@@ -683,7 +683,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -711,7 +711,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeletePublicDelegatedPrefixeRequest
 ):
     client = PublicDelegatedPrefixesClient(
@@ -735,14 +735,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = PublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -774,7 +774,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             public_delegated_prefix="public_delegated_prefix_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -787,7 +787,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = PublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -795,7 +795,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeletePublicDelegatedPrefixeRequest(),
             project="project_value",
             region="region_value",
@@ -833,7 +833,7 @@ def test_get_rest(
             parent_prefix="parent_prefix_value",
             region="region_value",
             self_link="self_link_value",
-            status=compute.PublicDelegatedPrefix.Status.ANNOUNCED,
+            status="status_value",
         )
 
         # Wrap the value into a proper Response obj
@@ -857,7 +857,7 @@ def test_get_rest(
     assert response.parent_prefix == "parent_prefix_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
-    assert response.status == compute.PublicDelegatedPrefix.Status.ANNOUNCED
+    assert response.status == "status_value"
 
 
 def test_get_rest_bad_request(
@@ -952,7 +952,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertPublicDelegatedPrefixeRequest
 ):
     client = PublicDelegatedPrefixesClient(
@@ -1000,7 +1000,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1028,7 +1028,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertPublicDelegatedPrefixeRequest
 ):
     client = PublicDelegatedPrefixesClient(
@@ -1051,14 +1051,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = PublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1088,7 +1088,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1101,7 +1101,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = PublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1109,7 +1109,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertPublicDelegatedPrefixeRequest(),
             project="project_value",
             region="region_value",
@@ -1289,7 +1289,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchPublicDelegatedPrefixeRequest
 ):
     client = PublicDelegatedPrefixesClient(
@@ -1341,7 +1341,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1369,7 +1369,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchPublicDelegatedPrefixeRequest
 ):
     client = PublicDelegatedPrefixesClient(
@@ -1396,14 +1396,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = PublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1438,7 +1438,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1451,7 +1451,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = PublicDelegatedPrefixesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1459,7 +1459,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchPublicDelegatedPrefixeRequest(),
             project="project_value",
             region="region_value",
