@@ -440,7 +440,7 @@ def test_region_backend_services_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -489,7 +489,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -517,7 +517,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -541,14 +541,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -580,7 +580,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             backend_service="backend_service_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -593,7 +593,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -601,7 +601,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteRegionBackendServiceRequest(),
             project="project_value",
             region="region_value",
@@ -638,17 +638,17 @@ def test_get_rest(
             health_checks=["health_checks_value"],
             id=205,
             kind="kind_value",
-            load_balancing_scheme=compute.BackendService.LoadBalancingScheme.EXTERNAL,
-            locality_lb_policy=compute.BackendService.LocalityLbPolicy.INVALID_LB_POLICY,
+            load_balancing_scheme="load_balancing_scheme_value",
+            locality_lb_policy="locality_lb_policy_value",
             name="name_value",
             network="network_value",
             port=453,
             port_name="port_name_value",
-            protocol=compute.BackendService.Protocol.GRPC,
+            protocol="protocol_value",
             region="region_value",
             security_policy="security_policy_value",
             self_link="self_link_value",
-            session_affinity=compute.BackendService.SessionAffinity.CLIENT_IP,
+            session_affinity="session_affinity_value",
             timeout_sec=1185,
         )
 
@@ -672,23 +672,17 @@ def test_get_rest(
     assert response.health_checks == ["health_checks_value"]
     assert response.id == 205
     assert response.kind == "kind_value"
-    assert (
-        response.load_balancing_scheme
-        == compute.BackendService.LoadBalancingScheme.EXTERNAL
-    )
-    assert (
-        response.locality_lb_policy
-        == compute.BackendService.LocalityLbPolicy.INVALID_LB_POLICY
-    )
+    assert response.load_balancing_scheme == "load_balancing_scheme_value"
+    assert response.locality_lb_policy == "locality_lb_policy_value"
     assert response.name == "name_value"
     assert response.network == "network_value"
     assert response.port == 453
     assert response.port_name == "port_name_value"
-    assert response.protocol == compute.BackendService.Protocol.GRPC
+    assert response.protocol == "protocol_value"
     assert response.region == "region_value"
     assert response.security_policy == "security_policy_value"
     assert response.self_link == "self_link_value"
-    assert response.session_affinity == compute.BackendService.SessionAffinity.CLIENT_IP
+    assert response.session_affinity == "session_affinity_value"
     assert response.timeout_sec == 1185
 
 
@@ -921,7 +915,7 @@ def test_get_health_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -969,7 +963,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -997,7 +991,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -1020,14 +1014,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1057,7 +1051,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1070,7 +1064,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1078,7 +1072,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRegionBackendServiceRequest(),
             project="project_value",
             region="region_value",
@@ -1255,7 +1249,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -1307,7 +1301,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1335,7 +1329,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -1362,14 +1356,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1404,7 +1398,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1417,7 +1411,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1425,7 +1419,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchRegionBackendServiceRequest(),
             project="project_value",
             region="region_value",
@@ -1436,7 +1430,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_update_rest(
+def test_update_unary_rest(
     transport: str = "rest", request_type=compute.UpdateRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -1488,7 +1482,7 @@ def test_update_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1516,7 +1510,7 @@ def test_update_rest(
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateRegionBackendServiceRequest
 ):
     client = RegionBackendServicesClient(
@@ -1543,14 +1537,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1585,7 +1579,7 @@ def test_update_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1598,7 +1592,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionBackendServicesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1606,7 +1600,7 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateRegionBackendServiceRequest(),
             project="project_value",
             region="region_value",
