@@ -615,20 +615,20 @@ def test_get_rest(
     with mock.patch.object(Session, "request") as req:
         # Designate an appropriate value for the returned response.
         return_value = compute.Commitment(
-            category=compute.Commitment.Category.CATEGORY_UNSPECIFIED,
+            category="category_value",
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             end_timestamp="end_timestamp_value",
             id=205,
             kind="kind_value",
             name="name_value",
-            plan=compute.Commitment.Plan.INVALID,
+            plan="plan_value",
             region="region_value",
             self_link="self_link_value",
             start_timestamp="start_timestamp_value",
-            status=compute.Commitment.Status.ACTIVE,
+            status="status_value",
             status_message="status_message_value",
-            type_=compute.Commitment.Type.ACCELERATOR_OPTIMIZED,
+            type_="type__value",
         )
 
         # Wrap the value into a proper Response obj
@@ -641,20 +641,20 @@ def test_get_rest(
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Commitment)
-    assert response.category == compute.Commitment.Category.CATEGORY_UNSPECIFIED
+    assert response.category == "category_value"
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.end_timestamp == "end_timestamp_value"
     assert response.id == 205
     assert response.kind == "kind_value"
     assert response.name == "name_value"
-    assert response.plan == compute.Commitment.Plan.INVALID
+    assert response.plan == "plan_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.start_timestamp == "start_timestamp_value"
-    assert response.status == compute.Commitment.Status.ACTIVE
+    assert response.status == "status_value"
     assert response.status_message == "status_message_value"
-    assert response.type_ == compute.Commitment.Type.ACCELERATOR_OPTIMIZED
+    assert response.type_ == "type__value"
 
 
 def test_get_rest_bad_request(
@@ -745,7 +745,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertRegionCommitmentRequest
 ):
     client = RegionCommitmentsClient(
@@ -754,9 +754,7 @@ def test_insert_rest(
 
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2"}
-    request_init["commitment_resource"] = compute.Commitment(
-        category=compute.Commitment.Category.CATEGORY_UNSPECIFIED
-    )
+    request_init["commitment_resource"] = compute.Commitment(category="category_value")
     request = request_type(request_init)
 
     # Mock the http request call within the method and fake a response.
@@ -793,7 +791,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -821,7 +819,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRegionCommitmentRequest
 ):
     client = RegionCommitmentsClient(
@@ -830,9 +828,7 @@ def test_insert_rest_bad_request(
 
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2"}
-    request_init["commitment_resource"] = compute.Commitment(
-        category=compute.Commitment.Category.CATEGORY_UNSPECIFIED
-    )
+    request_init["commitment_resource"] = compute.Commitment(category="category_value")
     request = request_type(request_init)
 
     # Mock the http request call within the method and fake a BadRequest error.
@@ -844,14 +840,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RegionCommitmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -876,12 +872,10 @@ def test_insert_rest_flattened(transport: str = "rest"):
         mock_args = dict(
             project="project_value",
             region="region_value",
-            commitment_resource=compute.Commitment(
-                category=compute.Commitment.Category.CATEGORY_UNSPECIFIED
-            ),
+            commitment_resource=compute.Commitment(category="category_value"),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -894,7 +888,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionCommitmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -902,13 +896,11 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRegionCommitmentRequest(),
             project="project_value",
             region="region_value",
-            commitment_resource=compute.Commitment(
-                category=compute.Commitment.Category.CATEGORY_UNSPECIFIED
-            ),
+            commitment_resource=compute.Commitment(category="category_value"),
         )
 
 
