@@ -422,7 +422,7 @@ def test_region_health_checks_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -471,7 +471,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -499,7 +499,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -523,14 +523,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -562,7 +562,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             health_check="health_check_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -575,7 +575,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -583,7 +583,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteRegionHealthCheckRequest(),
             project="project_value",
             region="region_value",
@@ -620,7 +620,7 @@ def test_get_rest(
             region="region_value",
             self_link="self_link_value",
             timeout_sec=1185,
-            type_=compute.HealthCheck.Type.GRPC,
+            type_="type__value",
             unhealthy_threshold=2046,
         )
 
@@ -644,7 +644,7 @@ def test_get_rest(
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.timeout_sec == 1185
-    assert response.type_ == compute.HealthCheck.Type.GRPC
+    assert response.type_ == "type__value"
     assert response.unhealthy_threshold == 2046
 
 
@@ -740,7 +740,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -786,7 +786,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -814,7 +814,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -835,14 +835,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -870,7 +870,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             health_check_resource=compute.HealthCheck(check_interval_sec=1884),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -883,7 +883,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -891,7 +891,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRegionHealthCheckRequest(),
             project="project_value",
             region="region_value",
@@ -1066,7 +1066,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -1116,7 +1116,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1144,7 +1144,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -1169,14 +1169,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1209,7 +1209,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             health_check_resource=compute.HealthCheck(check_interval_sec=1884),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1222,7 +1222,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1230,7 +1230,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchRegionHealthCheckRequest(),
             project="project_value",
             region="region_value",
@@ -1239,7 +1239,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_update_rest(
+def test_update_unary_rest(
     transport: str = "rest", request_type=compute.UpdateRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -1289,7 +1289,7 @@ def test_update_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1317,7 +1317,7 @@ def test_update_rest(
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateRegionHealthCheckRequest
 ):
     client = RegionHealthChecksClient(
@@ -1342,14 +1342,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1382,7 +1382,7 @@ def test_update_rest_flattened(transport: str = "rest"):
             health_check_resource=compute.HealthCheck(check_interval_sec=1884),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1395,7 +1395,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionHealthChecksClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1403,7 +1403,7 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateRegionHealthCheckRequest(),
             project="project_value",
             region="region_value",
