@@ -418,7 +418,7 @@ def test_region_instances_client_client_options_credentials_file(
         )
 
 
-def test_bulk_insert_rest(
+def test_bulk_insert_unary_rest(
     transport: str = "rest", request_type=compute.BulkInsertRegionInstanceRequest
 ):
     client = RegionInstancesClient(
@@ -466,7 +466,7 @@ def test_bulk_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.bulk_insert(request)
+        response = client.bulk_insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -494,7 +494,7 @@ def test_bulk_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_bulk_insert_rest_bad_request(
+def test_bulk_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.BulkInsertRegionInstanceRequest
 ):
     client = RegionInstancesClient(
@@ -517,14 +517,14 @@ def test_bulk_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.bulk_insert(request)
+        client.bulk_insert_unary(request)
 
 
-def test_bulk_insert_rest_from_dict():
-    test_bulk_insert_rest(request_type=dict)
+def test_bulk_insert_unary_rest_from_dict():
+    test_bulk_insert_unary_rest(request_type=dict)
 
 
-def test_bulk_insert_rest_flattened(transport: str = "rest"):
+def test_bulk_insert_unary_rest_flattened(transport: str = "rest"):
     client = RegionInstancesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -554,7 +554,7 @@ def test_bulk_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.bulk_insert(**mock_args)
+        client.bulk_insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -567,7 +567,7 @@ def test_bulk_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_bulk_insert_rest_flattened_error(transport: str = "rest"):
+def test_bulk_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionInstancesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -575,7 +575,7 @@ def test_bulk_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.bulk_insert(
+        client.bulk_insert_unary(
             compute.BulkInsertRegionInstanceRequest(),
             project="project_value",
             region="region_value",
