@@ -15,7 +15,6 @@
 #
 import os
 import mock
-import packaging.version
 
 import grpc
 from grpc.experimental import aio
@@ -24,6 +23,7 @@ import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 
 from requests import Response
+from requests import Request
 from requests.sessions import Session
 
 from google.api_core import client_options
@@ -31,33 +31,17 @@ from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
+from google.api_core import path_template
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.region_operations import RegionOperationsClient
 from google.cloud.compute_v1.services.region_operations import pagers
 from google.cloud.compute_v1.services.region_operations import transports
-from google.cloud.compute_v1.services.region_operations.transports.base import (
-    _GOOGLE_AUTH_VERSION,
-)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
-# through google-api-core:
-# - Delete the auth "less than" test cases
-# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
-requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
-    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
-    reason="This test requires google-auth < 1.25.0",
-)
-requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
-    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
-    reason="This test requires google-auth >= 1.25.0",
-)
-
-
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
 
@@ -196,7 +180,7 @@ def test_region_operations_client_client_options(
     options = client_options.ClientOptions(api_endpoint="squid.clam.whelk")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(transport=transport_name, client_options=options)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -205,6 +189,7 @@ def test_region_operations_client_client_options(
             client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -212,7 +197,7 @@ def test_region_operations_client_client_options(
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "never"}):
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class()
+            client = client_class(transport=transport_name)
             patched.assert_called_once_with(
                 credentials=None,
                 credentials_file=None,
@@ -221,6 +206,7 @@ def test_region_operations_client_client_options(
                 client_cert_source_for_mtls=None,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -228,7 +214,7 @@ def test_region_operations_client_client_options(
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "always"}):
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class()
+            client = client_class(transport=transport_name)
             patched.assert_called_once_with(
                 credentials=None,
                 credentials_file=None,
@@ -237,6 +223,7 @@ def test_region_operations_client_client_options(
                 client_cert_source_for_mtls=None,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -256,7 +243,7 @@ def test_region_operations_client_client_options(
     options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(transport=transport_name, client_options=options)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -265,6 +252,7 @@ def test_region_operations_client_client_options(
             client_cert_source_for_mtls=None,
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
 
@@ -307,7 +295,7 @@ def test_region_operations_client_mtls_env_auto(
         )
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class(client_options=options)
+            client = client_class(transport=transport_name, client_options=options)
 
             if use_client_cert_env == "false":
                 expected_client_cert_source = None
@@ -324,6 +312,7 @@ def test_region_operations_client_mtls_env_auto(
                 client_cert_source_for_mtls=expected_client_cert_source,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -348,7 +337,7 @@ def test_region_operations_client_mtls_env_auto(
                         expected_client_cert_source = client_cert_source_callback
 
                     patched.return_value = None
-                    client = client_class()
+                    client = client_class(transport=transport_name)
                     patched.assert_called_once_with(
                         credentials=None,
                         credentials_file=None,
@@ -357,6 +346,7 @@ def test_region_operations_client_mtls_env_auto(
                         client_cert_source_for_mtls=expected_client_cert_source,
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
+                        always_use_jwt_access=True,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -369,7 +359,7 @@ def test_region_operations_client_mtls_env_auto(
                 return_value=False,
             ):
                 patched.return_value = None
-                client = client_class()
+                client = client_class(transport=transport_name)
                 patched.assert_called_once_with(
                     credentials=None,
                     credentials_file=None,
@@ -378,6 +368,7 @@ def test_region_operations_client_mtls_env_auto(
                     client_cert_source_for_mtls=None,
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
+                    always_use_jwt_access=True,
                 )
 
 
@@ -392,7 +383,7 @@ def test_region_operations_client_client_options_scopes(
     options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(transport=transport_name, client_options=options)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -401,6 +392,7 @@ def test_region_operations_client_client_options_scopes(
             client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
 
@@ -415,7 +407,7 @@ def test_region_operations_client_client_options_credentials_file(
     options = client_options.ClientOptions(credentials_file="credentials.json")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(transport=transport_name, client_options=options)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file="credentials.json",
@@ -424,6 +416,7 @@ def test_region_operations_client_client_options_credentials_file(
             client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
 
@@ -434,9 +427,9 @@ def test_delete_rest(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
-    # Everything is optional in proto3 as far as the runtime is concerned,
-    # and we are mocking out the actual API, so just send an empty request.
-    request = request_type()
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2", "operation": "sample3"}
+    request = request_type(request_init)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -444,9 +437,9 @@ def test_delete_rest(
         return_value = compute.DeleteRegionOperationResponse()
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.DeleteRegionOperationResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.DeleteRegionOperationResponse.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
         response = client.delete(request)
@@ -455,12 +448,37 @@ def test_delete_rest(
     assert isinstance(response, compute.DeleteRegionOperationResponse)
 
 
+def test_delete_rest_bad_request(
+    transport: str = "rest", request_type=compute.DeleteRegionOperationRequest
+):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2", "operation": "sample3"}
+    request = request_type(request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.delete(request)
+
+
 def test_delete_rest_from_dict():
     test_delete_rest(request_type=dict)
 
 
-def test_delete_rest_flattened():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_delete_rest_flattened(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -468,31 +486,42 @@ def test_delete_rest_flattened():
         return_value = compute.DeleteRegionOperationResponse()
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.DeleteRegionOperationResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.DeleteRegionOperationResponse.to_json(return_value)
+
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
 
-        # Call the method with a truthy value for each flattened field,
-        # using the keyword arguments to the method.
-        client.delete(
+        # get arguments that satisfy an http rule for this method
+        sample_request = {
+            "project": "sample1",
+            "region": "sample2",
+            "operation": "sample3",
+        }
+
+        # get truthy value for each flattened field
+        mock_args = dict(
             project="project_value", region="region_value", operation="operation_value",
         )
+        mock_args.update(sample_request)
+        client.delete(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
         assert len(req.mock_calls) == 1
-        _, http_call, http_params = req.mock_calls[0]
-        body = http_params.get("data")
-        params = http_params.get("params")
-        assert "project_value" in http_call[1] + str(body) + str(params)
-        assert "region_value" in http_call[1] + str(body) + str(params)
-        assert "operation_value" in http_call[1] + str(body) + str(params)
+        _, args, _ = req.mock_calls[0]
+        assert path_template.validate(
+            "https://%s/compute/v1/projects/{project}/regions/{region}/operations/{operation}"
+            % client.transport._host,
+            args[1],
+        )
 
 
-def test_delete_rest_flattened_error():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_delete_rest_flattened_error(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -512,9 +541,9 @@ def test_get_rest(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
-    # Everything is optional in proto3 as far as the runtime is concerned,
-    # and we are mocking out the actual API, so just send an empty request.
-    request = request_type()
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2", "operation": "sample3"}
+    request = request_type(request_init)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -524,7 +553,6 @@ def test_get_rest(
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             end_time="end_time_value",
-            error=compute.Error(errors=[compute.Errors(code="code_value")]),
             http_error_message="http_error_message_value",
             http_error_status_code=2374,
             id=205,
@@ -542,14 +570,13 @@ def test_get_rest(
             target_id=947,
             target_link="target_link_value",
             user="user_value",
-            warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
         response = client.get(request)
@@ -560,7 +587,6 @@ def test_get_rest(
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.end_time == "end_time_value"
-    assert response.error == compute.Error(errors=[compute.Errors(code="code_value")])
     assert response.http_error_message == "http_error_message_value"
     assert response.http_error_status_code == 2374
     assert response.id == 205
@@ -578,18 +604,40 @@ def test_get_rest(
     assert response.target_id == 947
     assert response.target_link == "target_link_value"
     assert response.user == "user_value"
-    assert response.warnings == [
-        compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)
-    ]
     assert response.zone == "zone_value"
 
 
+def test_get_rest_bad_request(
+    transport: str = "rest", request_type=compute.GetRegionOperationRequest
+):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2", "operation": "sample3"}
+    request = request_type(request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.get(request)
+
+
 def test_get_rest_from_dict():
     test_get_rest(request_type=dict)
 
 
-def test_get_rest_flattened():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_get_rest_flattened(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -597,31 +645,42 @@ def test_get_rest_flattened():
         return_value = compute.Operation()
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.Operation.to_json(return_value)
+
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
 
-        # Call the method with a truthy value for each flattened field,
-        # using the keyword arguments to the method.
-        client.get(
+        # get arguments that satisfy an http rule for this method
+        sample_request = {
+            "project": "sample1",
+            "region": "sample2",
+            "operation": "sample3",
+        }
+
+        # get truthy value for each flattened field
+        mock_args = dict(
             project="project_value", region="region_value", operation="operation_value",
         )
+        mock_args.update(sample_request)
+        client.get(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
         assert len(req.mock_calls) == 1
-        _, http_call, http_params = req.mock_calls[0]
-        body = http_params.get("data")
-        params = http_params.get("params")
-        assert "project_value" in http_call[1] + str(body) + str(params)
-        assert "region_value" in http_call[1] + str(body) + str(params)
-        assert "operation_value" in http_call[1] + str(body) + str(params)
+        _, args, _ = req.mock_calls[0]
+        assert path_template.validate(
+            "https://%s/compute/v1/projects/{project}/regions/{region}/operations/{operation}"
+            % client.transport._host,
+            args[1],
+        )
 
 
-def test_get_rest_flattened_error():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_get_rest_flattened_error(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -641,26 +700,24 @@ def test_list_rest(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
-    # Everything is optional in proto3 as far as the runtime is concerned,
-    # and we are mocking out the actual API, so just send an empty request.
-    request = request_type()
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2"}
+    request = request_type(request_init)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Designate an appropriate value for the returned response.
         return_value = compute.OperationList(
             id="id_value",
-            items=[compute.Operation(client_operation_id="client_operation_id_value")],
             kind="kind_value",
             next_page_token="next_page_token_value",
             self_link="self_link_value",
-            warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.OperationList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.OperationList.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
         response = client.list(request)
@@ -668,21 +725,42 @@ def test_list_rest(
     # Establish that the response is the type that we expect.
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
-    assert response.items == [
-        compute.Operation(client_operation_id="client_operation_id_value")
-    ]
     assert response.kind == "kind_value"
     assert response.next_page_token == "next_page_token_value"
     assert response.self_link == "self_link_value"
-    assert response.warning == compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED)
+
+
+def test_list_rest_bad_request(
+    transport: str = "rest", request_type=compute.ListRegionOperationsRequest
+):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2"}
+    request = request_type(request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.list(request)
 
 
 def test_list_rest_from_dict():
     test_list_rest(request_type=dict)
 
 
-def test_list_rest_flattened():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_list_rest_flattened(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -690,30 +768,36 @@ def test_list_rest_flattened():
         return_value = compute.OperationList()
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.OperationList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.OperationList.to_json(return_value)
+
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
 
-        # Call the method with a truthy value for each flattened field,
-        # using the keyword arguments to the method.
-        client.list(
-            project="project_value", region="region_value",
-        )
+        # get arguments that satisfy an http rule for this method
+        sample_request = {"project": "sample1", "region": "sample2"}
+
+        # get truthy value for each flattened field
+        mock_args = dict(project="project_value", region="region_value",)
+        mock_args.update(sample_request)
+        client.list(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
         assert len(req.mock_calls) == 1
-        _, http_call, http_params = req.mock_calls[0]
-        body = http_params.get("data")
-        params = http_params.get("params")
-        assert "project_value" in http_call[1] + str(body) + str(params)
-        assert "region_value" in http_call[1] + str(body) + str(params)
+        _, args, _ = req.mock_calls[0]
+        assert path_template.validate(
+            "https://%s/compute/v1/projects/{project}/regions/{region}/operations"
+            % client.transport._host,
+            args[1],
+        )
 
 
-def test_list_rest_flattened_error():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_list_rest_flattened_error(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -725,11 +809,13 @@ def test_list_rest_flattened_error():
         )
 
 
-def test_list_pager():
+def test_list_rest_pager():
     client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
+        # TODO(kbandes): remove this mock unless there's a good reason for it.
+        # with mock.patch.object(path_template, 'transcode') as transcode:
         # Set the response as a series of pages
         response = (
             compute.OperationList(
@@ -751,16 +837,15 @@ def test_list_pager():
             return_val.status_code = 200
         req.side_effect = return_values
 
-        metadata = ()
-        pager = client.list(request={})
+        sample_request = {"project": "sample1", "region": "sample2"}
 
-        assert pager._metadata == metadata
+        pager = client.list(request=sample_request)
 
         results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, compute.Operation) for i in results)
 
-        pages = list(client.list(request={}).pages)
+        pages = list(client.list(request=sample_request).pages)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
 
@@ -772,9 +857,9 @@ def test_wait_rest(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
-    # Everything is optional in proto3 as far as the runtime is concerned,
-    # and we are mocking out the actual API, so just send an empty request.
-    request = request_type()
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2", "operation": "sample3"}
+    request = request_type(request_init)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -784,7 +869,6 @@ def test_wait_rest(
             creation_timestamp="creation_timestamp_value",
             description="description_value",
             end_time="end_time_value",
-            error=compute.Error(errors=[compute.Errors(code="code_value")]),
             http_error_message="http_error_message_value",
             http_error_status_code=2374,
             id=205,
@@ -802,14 +886,13 @@ def test_wait_rest(
             target_id=947,
             target_link="target_link_value",
             user="user_value",
-            warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
         response = client.wait(request)
@@ -820,7 +903,6 @@ def test_wait_rest(
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
     assert response.end_time == "end_time_value"
-    assert response.error == compute.Error(errors=[compute.Errors(code="code_value")])
     assert response.http_error_message == "http_error_message_value"
     assert response.http_error_status_code == 2374
     assert response.id == 205
@@ -838,18 +920,40 @@ def test_wait_rest(
     assert response.target_id == 947
     assert response.target_link == "target_link_value"
     assert response.user == "user_value"
-    assert response.warnings == [
-        compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)
-    ]
     assert response.zone == "zone_value"
 
 
+def test_wait_rest_bad_request(
+    transport: str = "rest", request_type=compute.WaitRegionOperationRequest
+):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"project": "sample1", "region": "sample2", "operation": "sample3"}
+    request = request_type(request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.wait(request)
+
+
 def test_wait_rest_from_dict():
     test_wait_rest(request_type=dict)
 
 
-def test_wait_rest_flattened():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_wait_rest_flattened(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -857,31 +961,42 @@ def test_wait_rest_flattened():
         return_value = compute.Operation()
 
         # Wrap the value into a proper Response obj
-        json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
+        json_return_value = compute.Operation.to_json(return_value)
+
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
 
-        # Call the method with a truthy value for each flattened field,
-        # using the keyword arguments to the method.
-        client.wait(
+        # get arguments that satisfy an http rule for this method
+        sample_request = {
+            "project": "sample1",
+            "region": "sample2",
+            "operation": "sample3",
+        }
+
+        # get truthy value for each flattened field
+        mock_args = dict(
             project="project_value", region="region_value", operation="operation_value",
         )
+        mock_args.update(sample_request)
+        client.wait(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
         assert len(req.mock_calls) == 1
-        _, http_call, http_params = req.mock_calls[0]
-        body = http_params.get("data")
-        params = http_params.get("params")
-        assert "project_value" in http_call[1] + str(body) + str(params)
-        assert "region_value" in http_call[1] + str(body) + str(params)
-        assert "operation_value" in http_call[1] + str(body) + str(params)
+        _, args, _ = req.mock_calls[0]
+        assert path_template.validate(
+            "https://%s/compute/v1/projects/{project}/regions/{region}/operations/{operation}/wait"
+            % client.transport._host,
+            args[1],
+        )
 
 
-def test_wait_rest_flattened_error():
-    client = RegionOperationsClient(credentials=ga_credentials.AnonymousCredentials(),)
+def test_wait_rest_flattened_error(transport: str = "rest"):
+    client = RegionOperationsClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -973,8 +1088,10 @@ def test_region_operations_base_transport():
         with pytest.raises(NotImplementedError):
             getattr(transport, method)(request=object())
 
+    with pytest.raises(NotImplementedError):
+        transport.close()
+
 
-@requires_google_auth_gte_1_25_0
 def test_region_operations_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
@@ -998,29 +1115,6 @@ def test_region_operations_base_transport_with_credentials_file():
         )
 
 
-@requires_google_auth_lt_1_25_0
-def test_region_operations_base_transport_with_credentials_file_old_google_auth():
-    # Instantiate the base transport with a credentials file
-    with mock.patch.object(
-        google.auth, "load_credentials_from_file", autospec=True
-    ) as load_creds, mock.patch(
-        "google.cloud.compute_v1.services.region_operations.transports.RegionOperationsTransport._prep_wrapped_messages"
-    ) as Transport:
-        Transport.return_value = None
-        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
-        transport = transports.RegionOperationsTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
-        )
-        load_creds.assert_called_once_with(
-            "credentials.json",
-            scopes=(
-                "https://www.googleapis.com/auth/compute",
-                "https://www.googleapis.com/auth/cloud-platform",
-            ),
-            quota_project_id="octopus",
-        )
-
-
 def test_region_operations_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
     with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
@@ -1032,7 +1126,6 @@ def test_region_operations_base_transport_with_adc():
         adc.assert_called_once()
 
 
-@requires_google_auth_gte_1_25_0
 def test_region_operations_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
     with mock.patch.object(google.auth, "default", autospec=True) as adc:
@@ -1048,21 +1141,6 @@ def test_region_operations_auth_adc():
         )
 
 
-@requires_google_auth_lt_1_25_0
-def test_region_operations_auth_adc_old_google_auth():
-    # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(google.auth, "default", autospec=True) as adc:
-        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
-        RegionOperationsClient()
-        adc.assert_called_once_with(
-            scopes=(
-                "https://www.googleapis.com/auth/compute",
-                "https://www.googleapis.com/auth/cloud-platform",
-            ),
-            quota_project_id=None,
-        )
-
-
 def test_region_operations_http_transport_client_cert_source_for_mtls():
     cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
@@ -1209,3 +1287,36 @@ def test_client_withDEFAULT_CLIENT_INFO():
             credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
+
+
+def test_transport_close():
+    transports = {
+        "rest": "_session",
+    }
+
+    for transport, close_name in transports.items():
+        client = RegionOperationsClient(
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport
+        )
+        with mock.patch.object(
+            type(getattr(client.transport, close_name)), "close"
+        ) as close:
+            with client:
+                close.assert_not_called()
+            close.assert_called_once()
+
+
+def test_client_ctx():
+    transports = [
+        "rest",
+    ]
+    for transport in transports:
+        client = RegionOperationsClient(
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport
+        )
+        # Test client calls underlying transport.
+        with mock.patch.object(type(client.transport), "close") as close:
+            close.assert_not_called()
+            with client:
+                pass
+            close.assert_called()
