@@ -440,7 +440,7 @@ def test_region_ssl_certificates_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteRegionSslCertificateRequest
 ):
     client = RegionSslCertificatesClient(
@@ -489,7 +489,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -517,7 +517,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteRegionSslCertificateRequest
 ):
     client = RegionSslCertificatesClient(
@@ -541,14 +541,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = RegionSslCertificatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -580,7 +580,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             ssl_certificate="ssl_certificate_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -593,7 +593,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionSslCertificatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -601,7 +601,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteRegionSslCertificateRequest(),
             project="project_value",
             region="region_value",
@@ -639,7 +639,7 @@ def test_get_rest(
             region="region_value",
             self_link="self_link_value",
             subject_alternative_names=["subject_alternative_names_value"],
-            type_=compute.SslCertificate.Type.MANAGED,
+            type_="type__value",
         )
 
         # Wrap the value into a proper Response obj
@@ -663,7 +663,7 @@ def test_get_rest(
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.subject_alternative_names == ["subject_alternative_names_value"]
-    assert response.type_ == compute.SslCertificate.Type.MANAGED
+    assert response.type_ == "type__value"
 
 
 def test_get_rest_bad_request(
@@ -758,7 +758,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertRegionSslCertificateRequest
 ):
     client = RegionSslCertificatesClient(
@@ -806,7 +806,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -834,7 +834,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRegionSslCertificateRequest
 ):
     client = RegionSslCertificatesClient(
@@ -857,14 +857,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RegionSslCertificatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -894,7 +894,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -907,7 +907,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionSslCertificatesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -915,7 +915,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRegionSslCertificateRequest(),
             project="project_value",
             region="region_value",
