@@ -440,7 +440,7 @@ def test_region_target_http_proxies_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteRegionTargetHttpProxyRequest
 ):
     client = RegionTargetHttpProxiesClient(
@@ -489,7 +489,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -517,7 +517,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteRegionTargetHttpProxyRequest
 ):
     client = RegionTargetHttpProxiesClient(
@@ -541,14 +541,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = RegionTargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -580,7 +580,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             target_http_proxy="target_http_proxy_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -593,7 +593,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionTargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -601,7 +601,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteRegionTargetHttpProxyRequest(),
             project="project_value",
             region="region_value",
@@ -754,7 +754,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertRegionTargetHttpProxyRequest
 ):
     client = RegionTargetHttpProxiesClient(
@@ -802,7 +802,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -830,7 +830,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRegionTargetHttpProxyRequest
 ):
     client = RegionTargetHttpProxiesClient(
@@ -853,14 +853,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RegionTargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -890,7 +890,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -903,7 +903,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionTargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -911,7 +911,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRegionTargetHttpProxyRequest(),
             project="project_value",
             region="region_value",
@@ -1088,7 +1088,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_set_url_map_rest(
+def test_set_url_map_unary_rest(
     transport: str = "rest", request_type=compute.SetUrlMapRegionTargetHttpProxyRequest
 ):
     client = RegionTargetHttpProxiesClient(
@@ -1140,7 +1140,7 @@ def test_set_url_map_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_url_map(request)
+        response = client.set_url_map_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1168,7 +1168,7 @@ def test_set_url_map_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_url_map_rest_bad_request(
+def test_set_url_map_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetUrlMapRegionTargetHttpProxyRequest
 ):
     client = RegionTargetHttpProxiesClient(
@@ -1195,14 +1195,14 @@ def test_set_url_map_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_url_map(request)
+        client.set_url_map_unary(request)
 
 
-def test_set_url_map_rest_from_dict():
-    test_set_url_map_rest(request_type=dict)
+def test_set_url_map_unary_rest_from_dict():
+    test_set_url_map_unary_rest(request_type=dict)
 
 
-def test_set_url_map_rest_flattened(transport: str = "rest"):
+def test_set_url_map_unary_rest_flattened(transport: str = "rest"):
     client = RegionTargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1235,7 +1235,7 @@ def test_set_url_map_rest_flattened(transport: str = "rest"):
             url_map_reference_resource=compute.UrlMapReference(url_map="url_map_value"),
         )
         mock_args.update(sample_request)
-        client.set_url_map(**mock_args)
+        client.set_url_map_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1248,7 +1248,7 @@ def test_set_url_map_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_url_map_rest_flattened_error(transport: str = "rest"):
+def test_set_url_map_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionTargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1256,7 +1256,7 @@ def test_set_url_map_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_url_map(
+        client.set_url_map_unary(
             compute.SetUrlMapRegionTargetHttpProxyRequest(),
             project="project_value",
             region="region_value",
