@@ -444,7 +444,7 @@ def test_region_target_https_proxies_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteRegionTargetHttpsProxyRequest
 ):
     client = RegionTargetHttpsProxiesClient(
@@ -493,7 +493,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -521,7 +521,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteRegionTargetHttpsProxyRequest
 ):
     client = RegionTargetHttpsProxiesClient(
@@ -545,14 +545,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -584,7 +584,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             target_https_proxy="target_https_proxy_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -597,7 +597,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -605,7 +605,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteRegionTargetHttpsProxyRequest(),
             project="project_value",
             region="region_value",
@@ -640,7 +640,7 @@ def test_get_rest(
             kind="kind_value",
             name="name_value",
             proxy_bind=True,
-            quic_override=compute.TargetHttpsProxy.QuicOverride.DISABLE,
+            quic_override="quic_override_value",
             region="region_value",
             self_link="self_link_value",
             server_tls_policy="server_tls_policy_value",
@@ -667,7 +667,7 @@ def test_get_rest(
     assert response.kind == "kind_value"
     assert response.name == "name_value"
     assert response.proxy_bind is True
-    assert response.quic_override == compute.TargetHttpsProxy.QuicOverride.DISABLE
+    assert response.quic_override == "quic_override_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
     assert response.server_tls_policy == "server_tls_policy_value"
@@ -768,7 +768,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertRegionTargetHttpsProxyRequest
 ):
     client = RegionTargetHttpsProxiesClient(
@@ -816,7 +816,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -844,7 +844,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRegionTargetHttpsProxyRequest
 ):
     client = RegionTargetHttpsProxiesClient(
@@ -867,14 +867,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -904,7 +904,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -917,7 +917,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -925,7 +925,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRegionTargetHttpsProxyRequest(),
             project="project_value",
             region="region_value",
@@ -1102,7 +1102,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_set_ssl_certificates_rest(
+def test_set_ssl_certificates_unary_rest(
     transport: str = "rest",
     request_type=compute.SetSslCertificatesRegionTargetHttpsProxyRequest,
 ):
@@ -1157,7 +1157,7 @@ def test_set_ssl_certificates_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_ssl_certificates(request)
+        response = client.set_ssl_certificates_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1185,7 +1185,7 @@ def test_set_ssl_certificates_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_ssl_certificates_rest_bad_request(
+def test_set_ssl_certificates_unary_rest_bad_request(
     transport: str = "rest",
     request_type=compute.SetSslCertificatesRegionTargetHttpsProxyRequest,
 ):
@@ -1215,14 +1215,14 @@ def test_set_ssl_certificates_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_ssl_certificates(request)
+        client.set_ssl_certificates_unary(request)
 
 
-def test_set_ssl_certificates_rest_from_dict():
-    test_set_ssl_certificates_rest(request_type=dict)
+def test_set_ssl_certificates_unary_rest_from_dict():
+    test_set_ssl_certificates_unary_rest(request_type=dict)
 
 
-def test_set_ssl_certificates_rest_flattened(transport: str = "rest"):
+def test_set_ssl_certificates_unary_rest_flattened(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1257,7 +1257,7 @@ def test_set_ssl_certificates_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_ssl_certificates(**mock_args)
+        client.set_ssl_certificates_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1270,7 +1270,7 @@ def test_set_ssl_certificates_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_ssl_certificates_rest_flattened_error(transport: str = "rest"):
+def test_set_ssl_certificates_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1278,7 +1278,7 @@ def test_set_ssl_certificates_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_ssl_certificates(
+        client.set_ssl_certificates_unary(
             compute.SetSslCertificatesRegionTargetHttpsProxyRequest(),
             project="project_value",
             region="region_value",
@@ -1289,7 +1289,7 @@ def test_set_ssl_certificates_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_url_map_rest(
+def test_set_url_map_unary_rest(
     transport: str = "rest", request_type=compute.SetUrlMapRegionTargetHttpsProxyRequest
 ):
     client = RegionTargetHttpsProxiesClient(
@@ -1341,7 +1341,7 @@ def test_set_url_map_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_url_map(request)
+        response = client.set_url_map_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1369,7 +1369,7 @@ def test_set_url_map_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_url_map_rest_bad_request(
+def test_set_url_map_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetUrlMapRegionTargetHttpsProxyRequest
 ):
     client = RegionTargetHttpsProxiesClient(
@@ -1396,14 +1396,14 @@ def test_set_url_map_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_url_map(request)
+        client.set_url_map_unary(request)
 
 
-def test_set_url_map_rest_from_dict():
-    test_set_url_map_rest(request_type=dict)
+def test_set_url_map_unary_rest_from_dict():
+    test_set_url_map_unary_rest(request_type=dict)
 
 
-def test_set_url_map_rest_flattened(transport: str = "rest"):
+def test_set_url_map_unary_rest_flattened(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1436,7 +1436,7 @@ def test_set_url_map_rest_flattened(transport: str = "rest"):
             url_map_reference_resource=compute.UrlMapReference(url_map="url_map_value"),
         )
         mock_args.update(sample_request)
-        client.set_url_map(**mock_args)
+        client.set_url_map_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1449,7 +1449,7 @@ def test_set_url_map_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_url_map_rest_flattened_error(transport: str = "rest"):
+def test_set_url_map_unary_rest_flattened_error(transport: str = "rest"):
     client = RegionTargetHttpsProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1457,7 +1457,7 @@ def test_set_url_map_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_url_map(
+        client.set_url_map_unary(
             compute.SetUrlMapRegionTargetHttpsProxyRequest(),
             project="project_value",
             region="region_value",
