@@ -581,7 +581,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteReservationRequest
 ):
     client = ReservationsClient(
@@ -626,7 +626,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -654,7 +654,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteReservationRequest
 ):
     client = ReservationsClient(
@@ -674,14 +674,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = ReservationsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -711,7 +711,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", zone="zone_value", reservation="reservation_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -724,7 +724,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = ReservationsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -732,7 +732,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteReservationRequest(),
             project="project_value",
             zone="zone_value",
@@ -762,7 +762,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetReservationRe
             satisfies_pzs=True,
             self_link="self_link_value",
             specific_reservation_required=True,
-            status=compute.Reservation.Status.CREATING,
+            status="status_value",
             zone="zone_value",
         )
 
@@ -785,7 +785,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetReservationRe
     assert response.satisfies_pzs is True
     assert response.self_link == "self_link_value"
     assert response.specific_reservation_required is True
-    assert response.status == compute.Reservation.Status.CREATING
+    assert response.status == "status_value"
     assert response.zone == "zone_value"
 
 
@@ -992,7 +992,7 @@ def test_get_iam_policy_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertReservationRequest
 ):
     client = ReservationsClient(
@@ -1040,7 +1040,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1068,7 +1068,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertReservationRequest
 ):
     client = ReservationsClient(
@@ -1091,14 +1091,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = ReservationsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1126,7 +1126,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             reservation_resource=compute.Reservation(commitment="commitment_value"),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1139,7 +1139,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = ReservationsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1147,7 +1147,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertReservationRequest(),
             project="project_value",
             zone="zone_value",
@@ -1320,7 +1320,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_resize_rest(
+def test_resize_unary_rest(
     transport: str = "rest", request_type=compute.ResizeReservationRequest
 ):
     client = ReservationsClient(
@@ -1368,7 +1368,7 @@ def test_resize_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.resize(request)
+        response = client.resize_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1396,7 +1396,7 @@ def test_resize_rest(
     assert response.zone == "zone_value"
 
 
-def test_resize_rest_bad_request(
+def test_resize_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.ResizeReservationRequest
 ):
     client = ReservationsClient(
@@ -1419,14 +1419,14 @@ def test_resize_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.resize(request)
+        client.resize_unary(request)
 
 
-def test_resize_rest_from_dict():
-    test_resize_rest(request_type=dict)
+def test_resize_unary_rest_from_dict():
+    test_resize_unary_rest(request_type=dict)
 
 
-def test_resize_rest_flattened(transport: str = "rest"):
+def test_resize_unary_rest_flattened(transport: str = "rest"):
     client = ReservationsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1461,7 +1461,7 @@ def test_resize_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.resize(**mock_args)
+        client.resize_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1474,7 +1474,7 @@ def test_resize_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_resize_rest_flattened_error(transport: str = "rest"):
+def test_resize_unary_rest_flattened_error(transport: str = "rest"):
     client = ReservationsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1482,7 +1482,7 @@ def test_resize_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.resize(
+        client.resize_unary(
             compute.ResizeReservationRequest(),
             project="project_value",
             zone="zone_value",
