@@ -605,7 +605,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteResourcePolicyRequest
 ):
     client = ResourcePoliciesClient(
@@ -654,7 +654,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -682,7 +682,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteResourcePolicyRequest
 ):
     client = ResourcePoliciesClient(
@@ -706,14 +706,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = ResourcePoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -745,7 +745,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             resource_policy="resource_policy_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -758,7 +758,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = ResourcePoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -766,7 +766,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteResourcePolicyRequest(),
             project="project_value",
             region="region_value",
@@ -800,7 +800,7 @@ def test_get_rest(
             name="name_value",
             region="region_value",
             self_link="self_link_value",
-            status=compute.ResourcePolicy.Status.CREATING,
+            status="status_value",
         )
 
         # Wrap the value into a proper Response obj
@@ -820,7 +820,7 @@ def test_get_rest(
     assert response.name == "name_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
-    assert response.status == compute.ResourcePolicy.Status.CREATING
+    assert response.status == "status_value"
 
 
 def test_get_rest_bad_request(
@@ -1032,7 +1032,7 @@ def test_get_iam_policy_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertResourcePolicyRequest
 ):
     client = ResourcePoliciesClient(
@@ -1080,7 +1080,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1108,7 +1108,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertResourcePolicyRequest
 ):
     client = ResourcePoliciesClient(
@@ -1131,14 +1131,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = ResourcePoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1168,7 +1168,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1181,7 +1181,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = ResourcePoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1189,7 +1189,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertResourcePolicyRequest(),
             project="project_value",
             region="region_value",
