@@ -571,7 +571,9 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterRequest):
+def test_delete_unary_rest(
+    transport: str = "rest", request_type=compute.DeleteRouterRequest
+):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -614,7 +616,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -642,7 +644,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteRouterRequest
 ):
     client = RoutersClient(
@@ -662,14 +664,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -699,7 +701,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", region="region_value", router="router_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -712,7 +714,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -720,7 +722,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteRouterRequest(),
             project="project_value",
             region="region_value",
@@ -1153,7 +1155,9 @@ def test_get_router_status_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterRequest):
+def test_insert_unary_rest(
+    transport: str = "rest", request_type=compute.InsertRouterRequest
+):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1161,7 +1165,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1199,7 +1203,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1227,7 +1231,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRouterRequest
 ):
     client = RoutersClient(
@@ -1237,7 +1241,7 @@ def test_insert_rest_bad_request(
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1250,14 +1254,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1283,13 +1287,11 @@ def test_insert_rest_flattened(transport: str = "rest"):
             project="project_value",
             region="region_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1302,7 +1304,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1310,14 +1312,12 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRouterRequest(),
             project="project_value",
             region="region_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
 
@@ -1477,7 +1477,9 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterRequest):
+def test_patch_unary_rest(
+    transport: str = "rest", request_type=compute.PatchRouterRequest
+):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1485,7 +1487,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2", "router": "sample3"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1523,7 +1525,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1551,7 +1553,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchRouterRequest
 ):
     client = RoutersClient(
@@ -1561,7 +1563,7 @@ def test_patch_rest_bad_request(
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2", "router": "sample3"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1574,14 +1576,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1612,13 +1614,11 @@ def test_patch_rest_flattened(transport: str = "rest"):
             region="region_value",
             router="router_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1631,7 +1631,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1639,15 +1639,13 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchRouterRequest(),
             project="project_value",
             region="region_value",
             router="router_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
 
@@ -1662,7 +1660,7 @@ def test_preview_rest(
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2", "router": "sample3"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1693,7 +1691,7 @@ def test_preview_rest_bad_request(
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2", "router": "sample3"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1744,9 +1742,7 @@ def test_preview_rest_flattened(transport: str = "rest"):
             region="region_value",
             router="router_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
         mock_args.update(sample_request)
@@ -1777,14 +1773,14 @@ def test_preview_rest_flattened_error(transport: str = "rest"):
             region="region_value",
             router="router_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
 
 
-def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterRequest):
+def test_update_unary_rest(
+    transport: str = "rest", request_type=compute.UpdateRouterRequest
+):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1792,7 +1788,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2", "router": "sample3"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1830,7 +1826,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1858,7 +1854,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateRouterRequest
 ):
     client = RoutersClient(
@@ -1868,7 +1864,7 @@ def test_update_rest_bad_request(
     # send a request that will satisfy transcoding
     request_init = {"project": "sample1", "region": "sample2", "router": "sample3"}
     request_init["router_resource"] = compute.Router(
-        bgp=compute.RouterBgp(advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM)
+        bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
     )
     request = request_type(request_init)
 
@@ -1881,14 +1877,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1919,13 +1915,11 @@ def test_update_rest_flattened(transport: str = "rest"):
             region="region_value",
             router="router_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1938,7 +1932,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = RoutersClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1946,15 +1940,13 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateRouterRequest(),
             project="project_value",
             region="region_value",
             router="router_value",
             router_resource=compute.Router(
-                bgp=compute.RouterBgp(
-                    advertise_mode=compute.RouterBgp.AdvertiseMode.CUSTOM
-                )
+                bgp=compute.RouterBgp(advertise_mode="advertise_mode_value")
             ),
         )
 
