@@ -394,7 +394,9 @@ def test_routes_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouteRequest):
+def test_delete_unary_rest(
+    transport: str = "rest", request_type=compute.DeleteRouteRequest
+):
     client = RoutesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -437,7 +439,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouteRe
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -465,7 +467,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouteRe
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteRouteRequest
 ):
     client = RoutesClient(
@@ -485,14 +487,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = RoutesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -516,7 +518,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", route="route_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -529,7 +531,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = RoutesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -537,7 +539,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteRouteRequest(), project="project_value", route="route_value",
         )
 
@@ -570,7 +572,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRouteRequest)
             next_hop_peering="next_hop_peering_value",
             next_hop_vpn_tunnel="next_hop_vpn_tunnel_value",
             priority=898,
-            route_type=compute.Route.RouteType.BGP,
+            route_type="route_type_value",
             self_link="self_link_value",
             tags=["tags_value"],
         )
@@ -600,7 +602,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRouteRequest)
     assert response.next_hop_peering == "next_hop_peering_value"
     assert response.next_hop_vpn_tunnel == "next_hop_vpn_tunnel_value"
     assert response.priority == 898
-    assert response.route_type == compute.Route.RouteType.BGP
+    assert response.route_type == "route_type_value"
     assert response.self_link == "self_link_value"
     assert response.tags == ["tags_value"]
 
@@ -682,7 +684,9 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouteRequest):
+def test_insert_unary_rest(
+    transport: str = "rest", request_type=compute.InsertRouteRequest
+):
     client = RoutesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -728,7 +732,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouteRe
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -756,7 +760,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouteRe
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertRouteRequest
 ):
     client = RoutesClient(
@@ -779,14 +783,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = RoutesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -815,7 +819,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -828,7 +832,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = RoutesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -836,7 +840,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertRouteRequest(),
             project="project_value",
             route_resource=compute.Route(
