@@ -420,7 +420,7 @@ def test_security_policies_client_client_options_credentials_file(
         )
 
 
-def test_add_rule_rest(
+def test_add_rule_unary_rest(
     transport: str = "rest", request_type=compute.AddRuleSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -468,7 +468,7 @@ def test_add_rule_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.add_rule(request)
+        response = client.add_rule_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -496,7 +496,7 @@ def test_add_rule_rest(
     assert response.zone == "zone_value"
 
 
-def test_add_rule_rest_bad_request(
+def test_add_rule_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.AddRuleSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -519,14 +519,14 @@ def test_add_rule_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.add_rule(request)
+        client.add_rule_unary(request)
 
 
-def test_add_rule_rest_from_dict():
-    test_add_rule_rest(request_type=dict)
+def test_add_rule_unary_rest_from_dict():
+    test_add_rule_unary_rest(request_type=dict)
 
 
-def test_add_rule_rest_flattened(transport: str = "rest"):
+def test_add_rule_unary_rest_flattened(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -556,7 +556,7 @@ def test_add_rule_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.add_rule(**mock_args)
+        client.add_rule_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -569,7 +569,7 @@ def test_add_rule_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_add_rule_rest_flattened_error(transport: str = "rest"):
+def test_add_rule_unary_rest_flattened_error(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -577,7 +577,7 @@ def test_add_rule_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.add_rule(
+        client.add_rule_unary(
             compute.AddRuleSecurityPolicyRequest(),
             project="project_value",
             security_policy="security_policy_value",
@@ -587,7 +587,7 @@ def test_add_rule_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -632,7 +632,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -660,7 +660,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -680,14 +680,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -713,7 +713,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", security_policy="security_policy_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -726,7 +726,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -734,7 +734,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteSecurityPolicyRequest(),
             project="project_value",
             security_policy="security_policy_value",
@@ -985,7 +985,7 @@ def test_get_rule_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1037,7 +1037,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1065,7 +1065,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1092,14 +1092,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1132,7 +1132,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1145,7 +1145,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1153,7 +1153,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertSecurityPolicyRequest(),
             project="project_value",
             security_policy_resource=compute.SecurityPolicy(
@@ -1441,7 +1441,7 @@ def test_list_preconfigured_expression_sets_rest_flattened_error(
         )
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1493,7 +1493,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1521,7 +1521,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1548,14 +1548,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1589,7 +1589,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1602,7 +1602,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1610,7 +1610,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchSecurityPolicyRequest(),
             project="project_value",
             security_policy="security_policy_value",
@@ -1624,7 +1624,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_patch_rule_rest(
+def test_patch_rule_unary_rest(
     transport: str = "rest", request_type=compute.PatchRuleSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1672,7 +1672,7 @@ def test_patch_rule_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch_rule(request)
+        response = client.patch_rule_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1700,7 +1700,7 @@ def test_patch_rule_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rule_rest_bad_request(
+def test_patch_rule_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchRuleSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1723,14 +1723,14 @@ def test_patch_rule_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch_rule(request)
+        client.patch_rule_unary(request)
 
 
-def test_patch_rule_rest_from_dict():
-    test_patch_rule_rest(request_type=dict)
+def test_patch_rule_unary_rest_from_dict():
+    test_patch_rule_unary_rest(request_type=dict)
 
 
-def test_patch_rule_rest_flattened(transport: str = "rest"):
+def test_patch_rule_unary_rest_flattened(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1760,7 +1760,7 @@ def test_patch_rule_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch_rule(**mock_args)
+        client.patch_rule_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1773,7 +1773,7 @@ def test_patch_rule_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rule_rest_flattened_error(transport: str = "rest"):
+def test_patch_rule_unary_rest_flattened_error(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1781,7 +1781,7 @@ def test_patch_rule_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch_rule(
+        client.patch_rule_unary(
             compute.PatchRuleSecurityPolicyRequest(),
             project="project_value",
             security_policy="security_policy_value",
@@ -1791,7 +1791,7 @@ def test_patch_rule_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_remove_rule_rest(
+def test_remove_rule_unary_rest(
     transport: str = "rest", request_type=compute.RemoveRuleSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1836,7 +1836,7 @@ def test_remove_rule_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.remove_rule(request)
+        response = client.remove_rule_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1864,7 +1864,7 @@ def test_remove_rule_rest(
     assert response.zone == "zone_value"
 
 
-def test_remove_rule_rest_bad_request(
+def test_remove_rule_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.RemoveRuleSecurityPolicyRequest
 ):
     client = SecurityPoliciesClient(
@@ -1884,14 +1884,14 @@ def test_remove_rule_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.remove_rule(request)
+        client.remove_rule_unary(request)
 
 
-def test_remove_rule_rest_from_dict():
-    test_remove_rule_rest(request_type=dict)
+def test_remove_rule_unary_rest_from_dict():
+    test_remove_rule_unary_rest(request_type=dict)
 
 
-def test_remove_rule_rest_flattened(transport: str = "rest"):
+def test_remove_rule_unary_rest_flattened(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1917,7 +1917,7 @@ def test_remove_rule_rest_flattened(transport: str = "rest"):
             project="project_value", security_policy="security_policy_value",
         )
         mock_args.update(sample_request)
-        client.remove_rule(**mock_args)
+        client.remove_rule_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1930,7 +1930,7 @@ def test_remove_rule_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_remove_rule_rest_flattened_error(transport: str = "rest"):
+def test_remove_rule_unary_rest_flattened_error(transport: str = "rest"):
     client = SecurityPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1938,7 +1938,7 @@ def test_remove_rule_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.remove_rule(
+        client.remove_rule_unary(
             compute.RemoveRuleSecurityPolicyRequest(),
             project="project_value",
             security_policy="security_policy_value",
