@@ -613,7 +613,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteServiceAttachmentRequest
 ):
     client = ServiceAttachmentsClient(
@@ -662,7 +662,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -690,7 +690,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteServiceAttachmentRequest
 ):
     client = ServiceAttachmentsClient(
@@ -714,14 +714,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = ServiceAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -753,7 +753,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             service_attachment="service_attachment_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -766,7 +766,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = ServiceAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -774,7 +774,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteServiceAttachmentRequest(),
             project="project_value",
             region="region_value",
@@ -801,7 +801,7 @@ def test_get_rest(
     with mock.patch.object(Session, "request") as req:
         # Designate an appropriate value for the returned response.
         return_value = compute.ServiceAttachment(
-            connection_preference=compute.ServiceAttachment.ConnectionPreference.ACCEPT_AUTOMATIC,
+            connection_preference="connection_preference_value",
             consumer_reject_lists=["consumer_reject_lists_value"],
             creation_timestamp="creation_timestamp_value",
             description="description_value",
@@ -827,10 +827,7 @@ def test_get_rest(
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.ServiceAttachment)
-    assert (
-        response.connection_preference
-        == compute.ServiceAttachment.ConnectionPreference.ACCEPT_AUTOMATIC
-    )
+    assert response.connection_preference == "connection_preference_value"
     assert response.consumer_reject_lists == ["consumer_reject_lists_value"]
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
@@ -1055,7 +1052,7 @@ def test_get_iam_policy_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertServiceAttachmentRequest
 ):
     client = ServiceAttachmentsClient(
@@ -1105,7 +1102,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1133,7 +1130,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertServiceAttachmentRequest
 ):
     client = ServiceAttachmentsClient(
@@ -1158,14 +1155,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = ServiceAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1199,7 +1196,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1212,7 +1209,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = ServiceAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1220,7 +1217,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertServiceAttachmentRequest(),
             project="project_value",
             region="region_value",
@@ -1401,7 +1398,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchServiceAttachmentRequest
 ):
     client = ServiceAttachmentsClient(
@@ -1455,7 +1452,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1483,7 +1480,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchServiceAttachmentRequest
 ):
     client = ServiceAttachmentsClient(
@@ -1512,14 +1509,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = ServiceAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1558,7 +1555,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1571,7 +1568,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = ServiceAttachmentsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1579,7 +1576,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchServiceAttachmentRequest(),
             project="project_value",
             region="region_value",
