@@ -397,7 +397,7 @@ def test_snapshots_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteSnapshotRequest
 ):
     client = SnapshotsClient(
@@ -442,7 +442,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -470,7 +470,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteSnapshotRequest
 ):
     client = SnapshotsClient(
@@ -490,14 +490,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = SnapshotsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -521,7 +521,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", snapshot="snapshot_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -534,7 +534,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = SnapshotsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -542,7 +542,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteSnapshotRequest(),
             project="project_value",
             snapshot="snapshot_value",
@@ -579,9 +579,9 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSnapshotReque
             self_link="self_link_value",
             source_disk="source_disk_value",
             source_disk_id="source_disk_id_value",
-            status=compute.Snapshot.Status.CREATING,
+            status="status_value",
             storage_bytes=1403,
-            storage_bytes_status=compute.Snapshot.StorageBytesStatus.UPDATING,
+            storage_bytes_status="storage_bytes_status_value",
             storage_locations=["storage_locations_value"],
         )
 
@@ -612,9 +612,9 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSnapshotReque
     assert response.self_link == "self_link_value"
     assert response.source_disk == "source_disk_value"
     assert response.source_disk_id == "source_disk_id_value"
-    assert response.status == compute.Snapshot.Status.CREATING
+    assert response.status == "status_value"
     assert response.storage_bytes == 1403
-    assert response.storage_bytes_status == compute.Snapshot.StorageBytesStatus.UPDATING
+    assert response.storage_bytes_status == "storage_bytes_status_value"
     assert response.storage_locations == ["storage_locations_value"]
 
 
@@ -1085,7 +1085,7 @@ def test_set_iam_policy_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_labels_rest(
+def test_set_labels_unary_rest(
     transport: str = "rest", request_type=compute.SetLabelsSnapshotRequest
 ):
     client = SnapshotsClient(
@@ -1133,7 +1133,7 @@ def test_set_labels_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_labels(request)
+        response = client.set_labels_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1161,7 +1161,7 @@ def test_set_labels_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_labels_rest_bad_request(
+def test_set_labels_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetLabelsSnapshotRequest
 ):
     client = SnapshotsClient(
@@ -1184,14 +1184,14 @@ def test_set_labels_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_labels(request)
+        client.set_labels_unary(request)
 
 
-def test_set_labels_rest_from_dict():
-    test_set_labels_rest(request_type=dict)
+def test_set_labels_unary_rest_from_dict():
+    test_set_labels_unary_rest(request_type=dict)
 
 
-def test_set_labels_rest_flattened(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened(transport: str = "rest"):
     client = SnapshotsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1221,7 +1221,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_labels(**mock_args)
+        client.set_labels_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1234,7 +1234,7 @@ def test_set_labels_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_labels_rest_flattened_error(transport: str = "rest"):
+def test_set_labels_unary_rest_flattened_error(transport: str = "rest"):
     client = SnapshotsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1242,7 +1242,7 @@ def test_set_labels_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_labels(
+        client.set_labels_unary(
             compute.SetLabelsSnapshotRequest(),
             project="project_value",
             resource="resource_value",
