@@ -401,7 +401,7 @@ def test_ssl_policies_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteSslPolicyRequest
 ):
     client = SslPoliciesClient(
@@ -446,7 +446,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -474,7 +474,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteSslPolicyRequest
 ):
     client = SslPoliciesClient(
@@ -494,14 +494,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = SslPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -525,7 +525,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", ssl_policy="ssl_policy_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -538,7 +538,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = SslPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -546,7 +546,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteSslPolicyRequest(),
             project="project_value",
             ssl_policy="ssl_policy_value",
@@ -573,9 +573,9 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSslPolicyRequ
             fingerprint="fingerprint_value",
             id=205,
             kind="kind_value",
-            min_tls_version=compute.SslPolicy.MinTlsVersion.TLS_1_0,
+            min_tls_version="min_tls_version_value",
             name="name_value",
-            profile=compute.SslPolicy.Profile.COMPATIBLE,
+            profile="profile_value",
             self_link="self_link_value",
         )
 
@@ -596,9 +596,9 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSslPolicyRequ
     assert response.fingerprint == "fingerprint_value"
     assert response.id == 205
     assert response.kind == "kind_value"
-    assert response.min_tls_version == compute.SslPolicy.MinTlsVersion.TLS_1_0
+    assert response.min_tls_version == "min_tls_version_value"
     assert response.name == "name_value"
-    assert response.profile == compute.SslPolicy.Profile.COMPATIBLE
+    assert response.profile == "profile_value"
     assert response.self_link == "self_link_value"
 
 
@@ -681,7 +681,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertSslPolicyRequest
 ):
     client = SslPoliciesClient(
@@ -729,7 +729,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -757,7 +757,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertSslPolicyRequest
 ):
     client = SslPoliciesClient(
@@ -780,14 +780,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = SslPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -816,7 +816,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -829,7 +829,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = SslPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -837,7 +837,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertSslPolicyRequest(),
             project="project_value",
             ssl_policy_resource=compute.SslPolicy(
@@ -1117,7 +1117,7 @@ def test_list_available_features_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchSslPolicyRequest
 ):
     client = SslPoliciesClient(
@@ -1165,7 +1165,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1193,7 +1193,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchSslPolicyRequest
 ):
     client = SslPoliciesClient(
@@ -1216,14 +1216,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = SslPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1253,7 +1253,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1266,7 +1266,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = SslPoliciesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1274,7 +1274,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchSslPolicyRequest(),
             project="project_value",
             ssl_policy="ssl_policy_value",
