@@ -603,7 +603,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -648,7 +648,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -676,7 +676,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -696,14 +696,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -729,7 +729,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", target_http_proxy="target_http_proxy_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -742,7 +742,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -750,7 +750,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteTargetHttpProxyRequest(),
             project="project_value",
             target_http_proxy="target_http_proxy_value",
@@ -887,7 +887,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -935,7 +935,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -963,7 +963,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -986,14 +986,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1022,7 +1022,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1035,7 +1035,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1043,7 +1043,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertTargetHttpProxyRequest(),
             project="project_value",
             target_http_proxy_resource=compute.TargetHttpProxy(
@@ -1215,7 +1215,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(
+def test_patch_unary_rest(
     transport: str = "rest", request_type=compute.PatchTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -1263,7 +1263,7 @@ def test_patch_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1291,7 +1291,7 @@ def test_patch_rest(
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -1314,14 +1314,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1351,7 +1351,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1364,7 +1364,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1372,7 +1372,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchTargetHttpProxyRequest(),
             project="project_value",
             target_http_proxy="target_http_proxy_value",
@@ -1382,7 +1382,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_url_map_rest(
+def test_set_url_map_unary_rest(
     transport: str = "rest", request_type=compute.SetUrlMapTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -1430,7 +1430,7 @@ def test_set_url_map_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_url_map(request)
+        response = client.set_url_map_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1458,7 +1458,7 @@ def test_set_url_map_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_url_map_rest_bad_request(
+def test_set_url_map_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetUrlMapTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
@@ -1481,14 +1481,14 @@ def test_set_url_map_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_url_map(request)
+        client.set_url_map_unary(request)
 
 
-def test_set_url_map_rest_from_dict():
-    test_set_url_map_rest(request_type=dict)
+def test_set_url_map_unary_rest_from_dict():
+    test_set_url_map_unary_rest(request_type=dict)
 
 
-def test_set_url_map_rest_flattened(transport: str = "rest"):
+def test_set_url_map_unary_rest_flattened(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1516,7 +1516,7 @@ def test_set_url_map_rest_flattened(transport: str = "rest"):
             url_map_reference_resource=compute.UrlMapReference(url_map="url_map_value"),
         )
         mock_args.update(sample_request)
-        client.set_url_map(**mock_args)
+        client.set_url_map_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1529,7 +1529,7 @@ def test_set_url_map_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_url_map_rest_flattened_error(transport: str = "rest"):
+def test_set_url_map_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetHttpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1537,7 +1537,7 @@ def test_set_url_map_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_url_map(
+        client.set_url_map_unary(
             compute.SetUrlMapTargetHttpProxyRequest(),
             project="project_value",
             target_http_proxy="target_http_proxy_value",
