@@ -602,7 +602,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteTargetInstanceRequest
 ):
     client = TargetInstancesClient(
@@ -651,7 +651,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -679,7 +679,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteTargetInstanceRequest
 ):
     client = TargetInstancesClient(
@@ -703,14 +703,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = TargetInstancesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -742,7 +742,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             target_instance="target_instance_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -755,7 +755,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetInstancesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -763,7 +763,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteTargetInstanceRequest(),
             project="project_value",
             zone="zone_value",
@@ -796,7 +796,7 @@ def test_get_rest(
             instance="instance_value",
             kind="kind_value",
             name="name_value",
-            nat_policy=compute.TargetInstance.NatPolicy.NO_NAT,
+            nat_policy="nat_policy_value",
             network="network_value",
             self_link="self_link_value",
             zone="zone_value",
@@ -818,7 +818,7 @@ def test_get_rest(
     assert response.instance == "instance_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
-    assert response.nat_policy == compute.TargetInstance.NatPolicy.NO_NAT
+    assert response.nat_policy == "nat_policy_value"
     assert response.network == "network_value"
     assert response.self_link == "self_link_value"
     assert response.zone == "zone_value"
@@ -916,7 +916,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertTargetInstanceRequest
 ):
     client = TargetInstancesClient(
@@ -964,7 +964,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -992,7 +992,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertTargetInstanceRequest
 ):
     client = TargetInstancesClient(
@@ -1015,14 +1015,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = TargetInstancesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1052,7 +1052,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1065,7 +1065,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetInstancesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1073,7 +1073,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertTargetInstanceRequest(),
             project="project_value",
             zone="zone_value",
