@@ -401,7 +401,7 @@ def test_target_pools_client_client_options_credentials_file(
         )
 
 
-def test_add_health_check_rest(
+def test_add_health_check_unary_rest(
     transport: str = "rest", request_type=compute.AddHealthCheckTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -451,7 +451,7 @@ def test_add_health_check_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.add_health_check(request)
+        response = client.add_health_check_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -479,7 +479,7 @@ def test_add_health_check_rest(
     assert response.zone == "zone_value"
 
 
-def test_add_health_check_rest_bad_request(
+def test_add_health_check_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.AddHealthCheckTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -504,14 +504,14 @@ def test_add_health_check_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.add_health_check(request)
+        client.add_health_check_unary(request)
 
 
-def test_add_health_check_rest_from_dict():
-    test_add_health_check_rest(request_type=dict)
+def test_add_health_check_unary_rest_from_dict():
+    test_add_health_check_unary_rest(request_type=dict)
 
 
-def test_add_health_check_rest_flattened(transport: str = "rest"):
+def test_add_health_check_unary_rest_flattened(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -548,7 +548,7 @@ def test_add_health_check_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.add_health_check(**mock_args)
+        client.add_health_check_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -561,7 +561,7 @@ def test_add_health_check_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_add_health_check_rest_flattened_error(transport: str = "rest"):
+def test_add_health_check_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -569,7 +569,7 @@ def test_add_health_check_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.add_health_check(
+        client.add_health_check_unary(
             compute.AddHealthCheckTargetPoolRequest(),
             project="project_value",
             region="region_value",
@@ -582,7 +582,7 @@ def test_add_health_check_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_add_instance_rest(
+def test_add_instance_unary_rest(
     transport: str = "rest", request_type=compute.AddInstanceTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -632,7 +632,7 @@ def test_add_instance_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.add_instance(request)
+        response = client.add_instance_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -660,7 +660,7 @@ def test_add_instance_rest(
     assert response.zone == "zone_value"
 
 
-def test_add_instance_rest_bad_request(
+def test_add_instance_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.AddInstanceTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -685,14 +685,14 @@ def test_add_instance_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.add_instance(request)
+        client.add_instance_unary(request)
 
 
-def test_add_instance_rest_from_dict():
-    test_add_instance_rest(request_type=dict)
+def test_add_instance_unary_rest_from_dict():
+    test_add_instance_unary_rest(request_type=dict)
 
 
-def test_add_instance_rest_flattened(transport: str = "rest"):
+def test_add_instance_unary_rest_flattened(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -727,7 +727,7 @@ def test_add_instance_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.add_instance(**mock_args)
+        client.add_instance_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -740,7 +740,7 @@ def test_add_instance_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_add_instance_rest_flattened_error(transport: str = "rest"):
+def test_add_instance_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -748,7 +748,7 @@ def test_add_instance_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.add_instance(
+        client.add_instance_unary(
             compute.AddInstanceTargetPoolRequest(),
             project="project_value",
             region="region_value",
@@ -939,7 +939,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -984,7 +984,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1012,7 +1012,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -1032,14 +1032,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1071,7 +1071,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             target_pool="target_pool_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1084,7 +1084,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1092,7 +1092,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteTargetPoolRequest(),
             project="project_value",
             region="region_value",
@@ -1124,7 +1124,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetTargetPoolReq
             name="name_value",
             region="region_value",
             self_link="self_link_value",
-            session_affinity=compute.TargetPool.SessionAffinity.CLIENT_IP,
+            session_affinity="session_affinity_value",
         )
 
         # Wrap the value into a proper Response obj
@@ -1148,7 +1148,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetTargetPoolReq
     assert response.name == "name_value"
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
-    assert response.session_affinity == compute.TargetPool.SessionAffinity.CLIENT_IP
+    assert response.session_affinity == "session_affinity_value"
 
 
 def test_get_rest_bad_request(
@@ -1368,7 +1368,7 @@ def test_get_health_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -1416,7 +1416,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1444,7 +1444,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -1467,14 +1467,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1502,7 +1502,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             target_pool_resource=compute.TargetPool(backup_pool="backup_pool_value"),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1515,7 +1515,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1523,7 +1523,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertTargetPoolRequest(),
             project="project_value",
             region="region_value",
@@ -1696,7 +1696,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_remove_health_check_rest(
+def test_remove_health_check_unary_rest(
     transport: str = "rest", request_type=compute.RemoveHealthCheckTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -1746,7 +1746,7 @@ def test_remove_health_check_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.remove_health_check(request)
+        response = client.remove_health_check_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1774,7 +1774,7 @@ def test_remove_health_check_rest(
     assert response.zone == "zone_value"
 
 
-def test_remove_health_check_rest_bad_request(
+def test_remove_health_check_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.RemoveHealthCheckTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -1799,14 +1799,14 @@ def test_remove_health_check_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.remove_health_check(request)
+        client.remove_health_check_unary(request)
 
 
-def test_remove_health_check_rest_from_dict():
-    test_remove_health_check_rest(request_type=dict)
+def test_remove_health_check_unary_rest_from_dict():
+    test_remove_health_check_unary_rest(request_type=dict)
 
 
-def test_remove_health_check_rest_flattened(transport: str = "rest"):
+def test_remove_health_check_unary_rest_flattened(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1843,7 +1843,7 @@ def test_remove_health_check_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.remove_health_check(**mock_args)
+        client.remove_health_check_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1856,7 +1856,7 @@ def test_remove_health_check_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_remove_health_check_rest_flattened_error(transport: str = "rest"):
+def test_remove_health_check_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1864,7 +1864,7 @@ def test_remove_health_check_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.remove_health_check(
+        client.remove_health_check_unary(
             compute.RemoveHealthCheckTargetPoolRequest(),
             project="project_value",
             region="region_value",
@@ -1877,7 +1877,7 @@ def test_remove_health_check_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_remove_instance_rest(
+def test_remove_instance_unary_rest(
     transport: str = "rest", request_type=compute.RemoveInstanceTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -1927,7 +1927,7 @@ def test_remove_instance_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.remove_instance(request)
+        response = client.remove_instance_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1955,7 +1955,7 @@ def test_remove_instance_rest(
     assert response.zone == "zone_value"
 
 
-def test_remove_instance_rest_bad_request(
+def test_remove_instance_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.RemoveInstanceTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -1980,14 +1980,14 @@ def test_remove_instance_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.remove_instance(request)
+        client.remove_instance_unary(request)
 
 
-def test_remove_instance_rest_from_dict():
-    test_remove_instance_rest(request_type=dict)
+def test_remove_instance_unary_rest_from_dict():
+    test_remove_instance_unary_rest(request_type=dict)
 
 
-def test_remove_instance_rest_flattened(transport: str = "rest"):
+def test_remove_instance_unary_rest_flattened(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2022,7 +2022,7 @@ def test_remove_instance_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.remove_instance(**mock_args)
+        client.remove_instance_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -2035,7 +2035,7 @@ def test_remove_instance_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_remove_instance_rest_flattened_error(transport: str = "rest"):
+def test_remove_instance_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2043,7 +2043,7 @@ def test_remove_instance_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.remove_instance(
+        client.remove_instance_unary(
             compute.RemoveInstanceTargetPoolRequest(),
             project="project_value",
             region="region_value",
@@ -2054,7 +2054,7 @@ def test_remove_instance_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_backup_rest(
+def test_set_backup_unary_rest(
     transport: str = "rest", request_type=compute.SetBackupTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -2102,7 +2102,7 @@ def test_set_backup_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_backup(request)
+        response = client.set_backup_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -2130,7 +2130,7 @@ def test_set_backup_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_backup_rest_bad_request(
+def test_set_backup_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetBackupTargetPoolRequest
 ):
     client = TargetPoolsClient(
@@ -2153,14 +2153,14 @@ def test_set_backup_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_backup(request)
+        client.set_backup_unary(request)
 
 
-def test_set_backup_rest_from_dict():
-    test_set_backup_rest(request_type=dict)
+def test_set_backup_unary_rest_from_dict():
+    test_set_backup_unary_rest(request_type=dict)
 
 
-def test_set_backup_rest_flattened(transport: str = "rest"):
+def test_set_backup_unary_rest_flattened(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2193,7 +2193,7 @@ def test_set_backup_rest_flattened(transport: str = "rest"):
             target_reference_resource=compute.TargetReference(target="target_value"),
         )
         mock_args.update(sample_request)
-        client.set_backup(**mock_args)
+        client.set_backup_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -2206,7 +2206,7 @@ def test_set_backup_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_backup_rest_flattened_error(transport: str = "rest"):
+def test_set_backup_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetPoolsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -2214,7 +2214,7 @@ def test_set_backup_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_backup(
+        client.set_backup_unary(
             compute.SetBackupTargetPoolRequest(),
             project="project_value",
             region="region_value",
