@@ -420,7 +420,7 @@ def test_target_tcp_proxies_client_client_options_credentials_file(
         )
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -465,7 +465,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -493,7 +493,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -513,14 +513,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -546,7 +546,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             project="project_value", target_tcp_proxy="target_tcp_proxy_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -559,7 +559,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -567,7 +567,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteTargetTcpProxyRequest(),
             project="project_value",
             target_tcp_proxy="target_tcp_proxy_value",
@@ -595,7 +595,7 @@ def test_get_rest(
             kind="kind_value",
             name="name_value",
             proxy_bind=True,
-            proxy_header=compute.TargetTcpProxy.ProxyHeader.NONE,
+            proxy_header="proxy_header_value",
             self_link="self_link_value",
             service="service_value",
         )
@@ -616,7 +616,7 @@ def test_get_rest(
     assert response.kind == "kind_value"
     assert response.name == "name_value"
     assert response.proxy_bind is True
-    assert response.proxy_header == compute.TargetTcpProxy.ProxyHeader.NONE
+    assert response.proxy_header == "proxy_header_value"
     assert response.self_link == "self_link_value"
     assert response.service == "service_value"
 
@@ -702,7 +702,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -750,7 +750,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -778,7 +778,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -801,14 +801,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -837,7 +837,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -850,7 +850,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -858,7 +858,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertTargetTcpProxyRequest(),
             project="project_value",
             target_tcp_proxy_resource=compute.TargetTcpProxy(
@@ -1030,7 +1030,7 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_set_backend_service_rest(
+def test_set_backend_service_unary_rest(
     transport: str = "rest", request_type=compute.SetBackendServiceTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -1078,7 +1078,7 @@ def test_set_backend_service_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_backend_service(request)
+        response = client.set_backend_service_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1106,7 +1106,7 @@ def test_set_backend_service_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_backend_service_rest_bad_request(
+def test_set_backend_service_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetBackendServiceTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -1129,14 +1129,14 @@ def test_set_backend_service_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_backend_service(request)
+        client.set_backend_service_unary(request)
 
 
-def test_set_backend_service_rest_from_dict():
-    test_set_backend_service_rest(request_type=dict)
+def test_set_backend_service_unary_rest_from_dict():
+    test_set_backend_service_unary_rest(request_type=dict)
 
 
-def test_set_backend_service_rest_flattened(transport: str = "rest"):
+def test_set_backend_service_unary_rest_flattened(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1166,7 +1166,7 @@ def test_set_backend_service_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.set_backend_service(**mock_args)
+        client.set_backend_service_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1179,7 +1179,7 @@ def test_set_backend_service_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_backend_service_rest_flattened_error(transport: str = "rest"):
+def test_set_backend_service_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1187,7 +1187,7 @@ def test_set_backend_service_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_backend_service(
+        client.set_backend_service_unary(
             compute.SetBackendServiceTargetTcpProxyRequest(),
             project="project_value",
             target_tcp_proxy="target_tcp_proxy_value",
@@ -1197,7 +1197,7 @@ def test_set_backend_service_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_set_proxy_header_rest(
+def test_set_proxy_header_unary_rest(
     transport: str = "rest", request_type=compute.SetProxyHeaderTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -1208,9 +1208,7 @@ def test_set_proxy_header_rest(
     request_init = {"project": "sample1", "target_tcp_proxy": "sample2"}
     request_init[
         "target_tcp_proxies_set_proxy_header_request_resource"
-    ] = compute.TargetTcpProxiesSetProxyHeaderRequest(
-        proxy_header=compute.TargetTcpProxiesSetProxyHeaderRequest.ProxyHeader.NONE
-    )
+    ] = compute.TargetTcpProxiesSetProxyHeaderRequest(proxy_header="proxy_header_value")
     request = request_type(request_init)
 
     # Mock the http request call within the method and fake a response.
@@ -1247,7 +1245,7 @@ def test_set_proxy_header_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.set_proxy_header(request)
+        response = client.set_proxy_header_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1275,7 +1273,7 @@ def test_set_proxy_header_rest(
     assert response.zone == "zone_value"
 
 
-def test_set_proxy_header_rest_bad_request(
+def test_set_proxy_header_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.SetProxyHeaderTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
@@ -1286,9 +1284,7 @@ def test_set_proxy_header_rest_bad_request(
     request_init = {"project": "sample1", "target_tcp_proxy": "sample2"}
     request_init[
         "target_tcp_proxies_set_proxy_header_request_resource"
-    ] = compute.TargetTcpProxiesSetProxyHeaderRequest(
-        proxy_header=compute.TargetTcpProxiesSetProxyHeaderRequest.ProxyHeader.NONE
-    )
+    ] = compute.TargetTcpProxiesSetProxyHeaderRequest(proxy_header="proxy_header_value")
     request = request_type(request_init)
 
     # Mock the http request call within the method and fake a BadRequest error.
@@ -1300,14 +1296,14 @@ def test_set_proxy_header_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.set_proxy_header(request)
+        client.set_proxy_header_unary(request)
 
 
-def test_set_proxy_header_rest_from_dict():
-    test_set_proxy_header_rest(request_type=dict)
+def test_set_proxy_header_unary_rest_from_dict():
+    test_set_proxy_header_unary_rest(request_type=dict)
 
 
-def test_set_proxy_header_rest_flattened(transport: str = "rest"):
+def test_set_proxy_header_unary_rest_flattened(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1333,11 +1329,11 @@ def test_set_proxy_header_rest_flattened(transport: str = "rest"):
             project="project_value",
             target_tcp_proxy="target_tcp_proxy_value",
             target_tcp_proxies_set_proxy_header_request_resource=compute.TargetTcpProxiesSetProxyHeaderRequest(
-                proxy_header=compute.TargetTcpProxiesSetProxyHeaderRequest.ProxyHeader.NONE
+                proxy_header="proxy_header_value"
             ),
         )
         mock_args.update(sample_request)
-        client.set_proxy_header(**mock_args)
+        client.set_proxy_header_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1350,7 +1346,7 @@ def test_set_proxy_header_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_set_proxy_header_rest_flattened_error(transport: str = "rest"):
+def test_set_proxy_header_unary_rest_flattened_error(transport: str = "rest"):
     client = TargetTcpProxiesClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1358,12 +1354,12 @@ def test_set_proxy_header_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.set_proxy_header(
+        client.set_proxy_header_unary(
             compute.SetProxyHeaderTargetTcpProxyRequest(),
             project="project_value",
             target_tcp_proxy="target_tcp_proxy_value",
             target_tcp_proxies_set_proxy_header_request_resource=compute.TargetTcpProxiesSetProxyHeaderRequest(
-                proxy_header=compute.TargetTcpProxiesSetProxyHeaderRequest.ProxyHeader.NONE
+                proxy_header="proxy_header_value"
             ),
         )
 
