@@ -573,7 +573,9 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(transport: str = "rest", request_type=compute.DeleteUrlMapRequest):
+def test_delete_unary_rest(
+    transport: str = "rest", request_type=compute.DeleteUrlMapRequest
+):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -616,7 +618,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteUrlMapR
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -644,7 +646,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteUrlMapR
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteUrlMapRequest
 ):
     client = UrlMapsClient(
@@ -664,14 +666,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -695,7 +697,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         # get truthy value for each flattened field
         mock_args = dict(project="project_value", url_map="url_map_value",)
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -708,7 +710,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -716,7 +718,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteUrlMapRequest(),
             project="project_value",
             url_map="url_map_value",
@@ -847,7 +849,9 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(transport: str = "rest", request_type=compute.InsertUrlMapRequest):
+def test_insert_unary_rest(
+    transport: str = "rest", request_type=compute.InsertUrlMapRequest
+):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -893,7 +897,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertUrlMapR
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -921,7 +925,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertUrlMapR
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertUrlMapRequest
 ):
     client = UrlMapsClient(
@@ -944,14 +948,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -980,7 +984,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -993,7 +997,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1001,7 +1005,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertUrlMapRequest(),
             project="project_value",
             url_map_resource=compute.UrlMap(
@@ -1010,7 +1014,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_invalidate_cache_rest(
+def test_invalidate_cache_unary_rest(
     transport: str = "rest", request_type=compute.InvalidateCacheUrlMapRequest
 ):
     client = UrlMapsClient(
@@ -1058,7 +1062,7 @@ def test_invalidate_cache_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.invalidate_cache(request)
+        response = client.invalidate_cache_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1086,7 +1090,7 @@ def test_invalidate_cache_rest(
     assert response.zone == "zone_value"
 
 
-def test_invalidate_cache_rest_bad_request(
+def test_invalidate_cache_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InvalidateCacheUrlMapRequest
 ):
     client = UrlMapsClient(
@@ -1109,14 +1113,14 @@ def test_invalidate_cache_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.invalidate_cache(request)
+        client.invalidate_cache_unary(request)
 
 
-def test_invalidate_cache_rest_from_dict():
-    test_invalidate_cache_rest(request_type=dict)
+def test_invalidate_cache_unary_rest_from_dict():
+    test_invalidate_cache_unary_rest(request_type=dict)
 
 
-def test_invalidate_cache_rest_flattened(transport: str = "rest"):
+def test_invalidate_cache_unary_rest_flattened(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1146,7 +1150,7 @@ def test_invalidate_cache_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.invalidate_cache(**mock_args)
+        client.invalidate_cache_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1159,7 +1163,7 @@ def test_invalidate_cache_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_invalidate_cache_rest_flattened_error(transport: str = "rest"):
+def test_invalidate_cache_unary_rest_flattened_error(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1167,7 +1171,7 @@ def test_invalidate_cache_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.invalidate_cache(
+        client.invalidate_cache_unary(
             compute.InvalidateCacheUrlMapRequest(),
             project="project_value",
             url_map="url_map_value",
@@ -1330,7 +1334,9 @@ def test_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_patch_rest(transport: str = "rest", request_type=compute.PatchUrlMapRequest):
+def test_patch_unary_rest(
+    transport: str = "rest", request_type=compute.PatchUrlMapRequest
+):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1376,7 +1382,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchUrlMapReq
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.patch(request)
+        response = client.patch_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1404,7 +1410,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchUrlMapReq
     assert response.zone == "zone_value"
 
 
-def test_patch_rest_bad_request(
+def test_patch_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.PatchUrlMapRequest
 ):
     client = UrlMapsClient(
@@ -1427,14 +1433,14 @@ def test_patch_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.patch(request)
+        client.patch_unary(request)
 
 
-def test_patch_rest_from_dict():
-    test_patch_rest(request_type=dict)
+def test_patch_unary_rest_from_dict():
+    test_patch_unary_rest(request_type=dict)
 
 
-def test_patch_rest_flattened(transport: str = "rest"):
+def test_patch_unary_rest_flattened(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1464,7 +1470,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.patch(**mock_args)
+        client.patch_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1477,7 +1483,7 @@ def test_patch_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_patch_rest_flattened_error(transport: str = "rest"):
+def test_patch_unary_rest_flattened_error(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1485,7 +1491,7 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.patch(
+        client.patch_unary(
             compute.PatchUrlMapRequest(),
             project="project_value",
             url_map="url_map_value",
@@ -1495,7 +1501,9 @@ def test_patch_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_update_rest(transport: str = "rest", request_type=compute.UpdateUrlMapRequest):
+def test_update_unary_rest(
+    transport: str = "rest", request_type=compute.UpdateUrlMapRequest
+):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1541,7 +1549,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateUrlMapR
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.update(request)
+        response = client.update_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -1569,7 +1577,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateUrlMapR
     assert response.zone == "zone_value"
 
 
-def test_update_rest_bad_request(
+def test_update_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.UpdateUrlMapRequest
 ):
     client = UrlMapsClient(
@@ -1592,14 +1600,14 @@ def test_update_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.update(request)
+        client.update_unary(request)
 
 
-def test_update_rest_from_dict():
-    test_update_rest(request_type=dict)
+def test_update_unary_rest_from_dict():
+    test_update_unary_rest(request_type=dict)
 
 
-def test_update_rest_flattened(transport: str = "rest"):
+def test_update_unary_rest_flattened(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1629,7 +1637,7 @@ def test_update_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.update(**mock_args)
+        client.update_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1642,7 +1650,7 @@ def test_update_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_update_rest_flattened_error(transport: str = "rest"):
+def test_update_unary_rest_flattened_error(transport: str = "rest"):
     client = UrlMapsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1650,7 +1658,7 @@ def test_update_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.update(
+        client.update_unary(
             compute.UpdateUrlMapRequest(),
             project="project_value",
             url_map="url_map_value",
