@@ -578,7 +578,7 @@ def test_aggregated_list_rest_pager():
             assert page_.raw_page.next_page_token == token
 
 
-def test_delete_rest(
+def test_delete_unary_rest(
     transport: str = "rest", request_type=compute.DeleteVpnTunnelRequest
 ):
     client = VpnTunnelsClient(
@@ -623,7 +623,7 @@ def test_delete_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.delete(request)
+        response = client.delete_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -651,7 +651,7 @@ def test_delete_rest(
     assert response.zone == "zone_value"
 
 
-def test_delete_rest_bad_request(
+def test_delete_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.DeleteVpnTunnelRequest
 ):
     client = VpnTunnelsClient(
@@ -671,14 +671,14 @@ def test_delete_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.delete(request)
+        client.delete_unary(request)
 
 
-def test_delete_rest_from_dict():
-    test_delete_rest(request_type=dict)
+def test_delete_unary_rest_from_dict():
+    test_delete_unary_rest(request_type=dict)
 
 
-def test_delete_rest_flattened(transport: str = "rest"):
+def test_delete_unary_rest_flattened(transport: str = "rest"):
     client = VpnTunnelsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -710,7 +710,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
             vpn_tunnel="vpn_tunnel_value",
         )
         mock_args.update(sample_request)
-        client.delete(**mock_args)
+        client.delete_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -723,7 +723,7 @@ def test_delete_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_delete_rest_flattened_error(transport: str = "rest"):
+def test_delete_unary_rest_flattened_error(transport: str = "rest"):
     client = VpnTunnelsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -731,7 +731,7 @@ def test_delete_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.delete(
+        client.delete_unary(
             compute.DeleteVpnTunnelRequest(),
             project="project_value",
             region="region_value",
@@ -770,7 +770,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetVpnTunnelRequ
             self_link="self_link_value",
             shared_secret="shared_secret_value",
             shared_secret_hash="shared_secret_hash_value",
-            status=compute.VpnTunnel.Status.ALLOCATING_RESOURCES,
+            status="status_value",
             target_vpn_gateway="target_vpn_gateway_value",
             vpn_gateway="vpn_gateway_value",
             vpn_gateway_interface=2229,
@@ -804,7 +804,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetVpnTunnelRequ
     assert response.self_link == "self_link_value"
     assert response.shared_secret == "shared_secret_value"
     assert response.shared_secret_hash == "shared_secret_hash_value"
-    assert response.status == compute.VpnTunnel.Status.ALLOCATING_RESOURCES
+    assert response.status == "status_value"
     assert response.target_vpn_gateway == "target_vpn_gateway_value"
     assert response.vpn_gateway == "vpn_gateway_value"
     assert response.vpn_gateway_interface == 2229
@@ -898,7 +898,7 @@ def test_get_rest_flattened_error(transport: str = "rest"):
         )
 
 
-def test_insert_rest(
+def test_insert_unary_rest(
     transport: str = "rest", request_type=compute.InsertVpnTunnelRequest
 ):
     client = VpnTunnelsClient(
@@ -946,7 +946,7 @@ def test_insert_rest(
         json_return_value = compute.Operation.to_json(return_value)
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-        response = client.insert(request)
+        response = client.insert_unary(request)
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, compute.Operation)
@@ -974,7 +974,7 @@ def test_insert_rest(
     assert response.zone == "zone_value"
 
 
-def test_insert_rest_bad_request(
+def test_insert_unary_rest_bad_request(
     transport: str = "rest", request_type=compute.InsertVpnTunnelRequest
 ):
     client = VpnTunnelsClient(
@@ -997,14 +997,14 @@ def test_insert_rest_bad_request(
         response_value.status_code = 400
         response_value.request = Request()
         req.return_value = response_value
-        client.insert(request)
+        client.insert_unary(request)
 
 
-def test_insert_rest_from_dict():
-    test_insert_rest(request_type=dict)
+def test_insert_unary_rest_from_dict():
+    test_insert_unary_rest(request_type=dict)
 
 
-def test_insert_rest_flattened(transport: str = "rest"):
+def test_insert_unary_rest_flattened(transport: str = "rest"):
     client = VpnTunnelsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1034,7 +1034,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
             ),
         )
         mock_args.update(sample_request)
-        client.insert(**mock_args)
+        client.insert_unary(**mock_args)
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1047,7 +1047,7 @@ def test_insert_rest_flattened(transport: str = "rest"):
         )
 
 
-def test_insert_rest_flattened_error(transport: str = "rest"):
+def test_insert_unary_rest_flattened_error(transport: str = "rest"):
     client = VpnTunnelsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1055,7 +1055,7 @@ def test_insert_rest_flattened_error(transport: str = "rest"):
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
-        client.insert(
+        client.insert_unary(
             compute.InsertVpnTunnelRequest(),
             project="project_value",
             region="region_value",
